﻿namespace XtraReportSerialization {
    using System;
    using System.Collections;
    using System.Collections.Generic;
    using System.Drawing.Printing;
    using System.Linq;
    using System.Text;
    using DevExpress.XtraEditors;
    using DevExpress.XtraReports.UI;
    using Soneta.Business;
    using Soneta.Business.UI.DxReports;
    using Soneta.Handel;
    using Soneta.Kasa;
    using Soneta.Langs;
    using Soneta.Tools;
    using Soneta.Types;
    using Soneta.CRM;
    
    public class Sprzedaz : DevExpress.XtraReports.UI.XtraReport {

        // Report Script Start
        
        public sealed class MyParametryWydruku : ContextBase, IPreValidate
        {
            public MyParametryWydruku(Context cx) : base(cx)
            {
                DefDokHandlowego def;
                cx.Get(out def);
                Rabat = def != null ? def.DrukowanieCenyIRabatu : false;
            }
        
            [Priority(250)]
            [Translate]
            public bool Duplikat { get; set; }
        
            [Caption("Drukuj rabat"), Priority(500)]
            public bool Rabat { get; set; }
        
            [Caption("Wg cen"), Priority(1000)]
            public bool WgCen { get; set; }
        
            public bool IsReadOnlyWgCen()
            {
                return !Context.Contains(typeof(DokumentHandlowy));
            }
        
            bool IPreValidate.PreValidate()
            {
                var jestZatwierdzany = Context.Contains(
                    typeof(ParametryWydrukuDokumentu.Zatwierdzany));
                DokumentHandlowy doc;
                return !(!jestZatwierdzany || jestZatwierdzany && Context.Get<DokumentHandlowy>(out doc) && doc.Definicja.PokazParametryWydruku == ParametryWydrukuMonit.Pokaz);
            }
        
            sealed class PozycjaWgCenyŚredniej : PozycjaWgCeny
            {
                private DoubleCy _cenaNettoPoRabacie;
                private DoubleCy _cenaBruttoPoRabacie;
        
                public PozycjaWgCenyŚredniej(PozycjaDokHandlowego poz, int lp) : base(poz, lp)
                {
                    _cenaNettoPoRabacie = poz.CenaNettoPoRabacie;
                    _cenaBruttoPoRabacie = poz.CenaBruttoPoRabacie;
                    if (poz.RodzajKorekty != RodzajKorektyPozycji.Brak)
                    {
                    }
                }
                public new void Dodaj(PozycjaDokHandlowego p)
                {
                    base.Dodaj(p);
                    if (!Ilosc.IsZero)
                    {
                        _cenaNettoPoRabacie = new DoubleCy((double)WartoscCy.Value / Ilosc.Value, _cenaNettoPoRabacie.Symbol);
                        _cenaNettoPoRabacie = _cenaNettoPoRabacie.Round(2);
                        _cenaBruttoPoRabacie = new DoubleCy((double)(WartoscCy.Value + Stawka.VatOdNetto(WartoscCy.Value)) / Ilosc.Value, _cenaBruttoPoRabacie.Symbol);
                        _cenaBruttoPoRabacie = _cenaBruttoPoRabacie.Round(2);
                    }
                    if (p.RodzajKorekty != RodzajKorektyPozycji.Brak)
                    {
                    }
                }
                public override DoubleCy CenaNettoPoRabacie
                {
                    get { return _cenaNettoPoRabacie; }
                }
        
                public override DoubleCy CenaBruttoPoRabacie
                {
                    get { return _cenaBruttoPoRabacie; }
                }
            }
        
            [Hidden]
            public IPozycjaDokHandlowego[] PozycjeRazemWgTowaruICenyZKorektami
            {
                get
                {
                    Hashtable ht = new Hashtable();
                    Hashtable htK = new Hashtable();
                    ArrayList arr = new ArrayList();
                    ArrayList arrK = new ArrayList();
                    int lp = 0;
                    if (WgCen)
                    {
                        DokumentHandlowy
                              dokument = (DokumentHandlowy)Context[typeof(DokumentHandlowy)],
                              korygowany = dokument.DokumentKorygowany;
                        bool wszystkoPrzed = !dokument.Module.Config.Wydruki.TylkoRóżnicePrzedKorektą;
                        bool wszystko = korygowany == null
                            || !dokument.Module.Config.Wydruki.TylkoRóżniceNaKorekcie;
        
                        foreach (PozycjaDokHandlowego poz in dokument.Pozycje)
                        {
        
                            if (poz.PozycjaKorygowana != null)
                            {
                                PozycjaWgCeny.Klucz klucz = new PozycjaWgCeny.Klucz(poz.PozycjaKorygowana);
        
                                PozycjaWgCenyŚredniej p = (PozycjaWgCenyŚredniej)ht[klucz];
                                PozycjaWgCenyŚredniej pK = (PozycjaWgCenyŚredniej)htK[klucz];
                                if (p == null || pK == null)
                                {
                                    lp++;
                                    if (wszystko || poz.RodzajKorekty != RodzajKorektyPozycji.Brak)
                                        ht[klucz] = new PozycjaWgCenyŚredniej(poz, lp);
                                    if (wszystkoPrzed || poz.RodzajKorekty != RodzajKorektyPozycji.Brak)
                                        htK[klucz] = new PozycjaWgCenyŚredniej(poz.PozycjaKorygowana, lp);
                                }
                                else
                                {
                                    p.Dodaj(poz);
                                    pK.Dodaj(poz.PozycjaKorygowana);
                                }
                            }
                            else
                            {
                                if (!wszystko && poz.RodzajKorekty == RodzajKorektyPozycji.Brak) continue;
                                PozycjaWgCeny.Klucz klucz = new PozycjaWgCeny.Klucz(poz);
                                PozycjaWgCeny p = (PozycjaWgCeny)ht[klucz];
                                if (p == null)
                                {
                                    ht[klucz] = new PozycjaWgCeny(poz, ++lp);
                                }
                                else
                                {
                                    p.Dodaj(poz);
                                }
                            }
                        }
                    }
        
                    arrK.AddRange(htK.Values);
                    arrK.Sort(PozycjaDokHandlowegoProxy.LpComparer);
        
                    arr.AddRange(ht.Values);
                    arr.Sort(PozycjaDokHandlowegoProxy.LpComparer);
        
                    arrK.AddRange(arr);
                    return arrK.OfType<IPozycjaDokHandlowego>().ToArray();
                }
            }
        }
        
        [Context(CreateOnly = false)]
        public MyParametryWydruku Parametry { get; set; }
        
        string Elo(object o)
        {
            return "ELo";
        }
        void HideColumns(object sender, PrintEventArgs _)
        {
            var d = GetCurrentRow() as DokumentHandlowy;
            bool rabat = Parametry.Rabat;
            if (sender == Grid1Lista)
            {
                var OplataKontrahent = Soneta.
                    OplataCukrowa.
                    OplataCukrowaModule.
                    GetInstance(Parametry.Context.Session).
                    OpCukrKontrah.
                    GetOplataCukrowaKontrahent(d.Kontrahent, false);
                    
              var PodatekCukrowy = OplataKontrahent != null && 
                    OplataKontrahent.NaliczanieOplatyCukrowej == Soneta.OplataCukrowa.NaliczanieOplatyCukrowej.Wyodrebniona;
                    
                            
                
                    var jestRozny = false;
                    foreach(var p in d.Pozycje)
                            {
                                var BezOc = Soneta.OplataCukrowa.
            OplataCukrowaModule.GetInstance(Parametry.Context.Session).
            OpCukrPozDok.GetOplataCukrowaPozycjaDokHandlowego(p).
            CenaBezOC;
                                if(p.Cena != BezOc)
                                {            
                                    jestRozny = true;
                                }
                            }
                      if(!jestRozny)
                      {
                            PodatekCukrowy = false;
                        }
                if (!PodatekCukrowy)
                {                
                    tableCell21.HideMe();
                    tableCell20.HideMe();
                    tableCell24.HideMe();
                    tableCell22.HideMe();
                }
                    else
                    {
                        if(d.OdBrutto){
                        tableCell21.Text = "Cena brutto bez OC";
                tableCell20.Text = "Cena brutto z OC";
                        }
                    }
        
                if (!d.JestSWW || d.Wydruk.JestUproszczony)
                {
                    _sww.HideMe();
                    _tableCell28.HideMe();
                }
        
                if (!d.Korekta || d.JestKorektaRabatowa)
                {
                    _rodzajKorektyCol.HideMe();
                    _tableCell29.HideMe();
                }
        
                if (d.Definicja.SumyVAT == SposobLiczeniaSumVAT.NieLiczyć ||
                    d.Wydruk.JestUproszczony)
                {
                    vat.HideMe();
                    _tableCell26.HideMe();
                }
        
                if (!(d.JestRabat && rabat && !d.Definicja.CenaWartosc0) ||
                    d.JestKorektaRabatowa)
                {
                    _grid1RabatP.HideMe();
                    _tableCell22.HideMe();
                    _grid1CenaPrzedRabatem.HideMe();
                    _tableCell21.HideMe();
                }
        
                if (d.OdBrutto || d.Wydruk.JestUproszczony ||
                    d.JestKorektaRabatowa || PodatekCukrowy)
                {
                    _grid1CenaNettoPoRabacie.HideMe();
                    tableCell23.HideMe();
                }
                if (
                    d.Platnosci.Any(x => !x.SposobZaplaty.Odroczony)
                    && (d.Definicja.EdycjaWartosci == EdycjaWartosciDokumentu.ZakazZmiany || d.Definicja.EdycjaWartosci == EdycjaWartosciDokumentu.SprawdzajKwotęPLN))
                    label2.Dispose();
        
                if (!d.OdBrutto || d.Wydruk.JestUproszczony ||
                    d.JestKorektaRabatowa)
                {
                    _grid1CenaBruttoPoRabacie.HideMe();
                    _tableCell24.HideMe();
                }
        
                if (d.Wydruk.JestUproszczony)
                {
                    wartosc.HideMe();
                    _tableCell25.HideMe();
                }
        
                if (d.Wydruk.JestUproszczony || d.JestKorektaRabatowa)
                {
                    _pozycjeIlosc.HideMe();
                    _tableCell19.HideMe();
                    _pozycjeIloscSym.HideMe();
                    _tableCell20.HideMe();
                }
            }
            else if (sender == detailReportWgCen)
            {
                if (!d.JestSWW || d.Wydruk.JestUproszczony)
                {
                    _tableCell156.HideMe();
                    _tableCell181.HideMe();
                }
        
                if (!d.Korekta || d.JestKorektaRabatowa)
                {
                    _tableCell157.HideMe();
                    _tableCell182.HideMe();
                }
        
                if (d.Definicja.SumyVAT == SposobLiczeniaSumVAT.NieLiczyć ||
                    d.Wydruk.JestUproszczony)
                {
                    _tableCell155.HideMe();
                    _tableCell80.HideMe();
                }
        
                if (!(d.JestRabat && rabat && !d.Definicja.CenaWartosc0) ||
                    d.JestKorektaRabatowa)
                {
                    _tableCell151.HideMe();
                    _tableCell176.HideMe();
                }
        
                if (d.OdBrutto || d.Wydruk.JestUproszczony ||
                    d.JestKorektaRabatowa)
                {
                    _tableCell152.HideMe();
                    _tableCell177.HideMe();
                }
        
                if (!d.OdBrutto || d.Wydruk.JestUproszczony ||
                    d.JestKorektaRabatowa)
                {
                    _tableCell153.HideMe();
                    _tableCell178.HideMe();
                }
            }
            else if (sender == Grid_SumyVatLista)
            {
                if (d.Wydruk.JestUproszczony)
                {
                    Grid_SumyVat_NettoCy.HideMe();
                    tableCell69.HideMe();
                    tableCell73.HideMe();
                }
        
                if (d.KrajPodatkuVat == d.Module.Core.KrajeTbl.Poland)
                {
                    tableCell70.HideMe(tableCell19.Name);
                    tableCell66.HideMe(tableCell5.Name);
                    tableCell74.HideMe(tableCell15.Name);
                }
                else
                {
                    tableCell19.HideMe(tableCell70.Name);
                    tableCell5.HideMe(tableCell66.Name);
                    tableCell15.HideMe(tableCell74.Name);
                }
            }
            else if (sender == SectionVATZamowienia)
            {
                if (d.Wydruk.JestUproszczony)
                {
                    Grid_VATZamowienia_NettoCy.HideMe();
                    tableCell47.HideMe();
                    tableCell51.HideMe();
                }
            }
            else if (sender == SectionVATZaliczkowego)
            {
                if (d.Wydruk.JestUproszczony)
                {
                    Grid_VATZaliczkowego_NettoCy.HideMe();
                    tableCell58.HideMe();
                    tableCell62.HideMe();
                }
            }
            else if (sender == niezapłaconeLista)
            {
                if (!d.InnyPłatnik)
                {
                    platnik.HideMe(0);
                    _tableCell107.HideMe(0);
                }
            }
        }
        
        void Sprzedaz_DataSourceRowChanged(object __, DataSourceRowEventArgs e)
        {
            SuspendLayout();
            var d = (DokumentHandlowy)((IList)DataSource)[e.CurrentRow];
            Parametry.Context.Set(Parametry.Context.Session[d]);
            var k = new KopiaDokumentu(d, Parametry.Duplikat ? TypKopiiDokumentu.Duplikat : TypKopiiDokumentu.Oryginał)
            {
                Culture = "pl".TranslateIgnore()
            };
        
            databaseSubReport1.ReportSource.DataSource = new List<KopiaDokumentu> { k };
            databaseSubReport2.ReportSource.DataSource = new List<DokumentHandlowy> { d };
        
            bool noop, korekta;
            bool
                końcowy = d.JestKoncowy(out noop),
                jestMniejszaKwota = d.LiczonaOd == SposobLiczeniaVAT.OdNetto ? d.SumaPozycji.Netto != d.Suma.Netto : d.SumaPozycji.Brutto != d.Suma.Brutto,
                zaliczka = d.JestDokZaliczkowy(out korekta),
                szVisible = d.DokumentyZaliczkowe.Length > 0;
        
            if (szVisible && d.Korekta && d.DokumentKorygowany != null)
            {
                szVisible = d.JestDokZaliczkowy();
            }
        
            Array.ForEach(new Dictionary<XRControl, string>
            {
                  { tr_PoprzednieKorekty, "Wydruk.CzyDrukowacNumeryKorekt" }
                , { tr_DokumentyPowiazane1, "Wydruk.CzyDrukowacNumeryPowiazanych" }
                , { tr_DokumentyPowiazane2, "Wydruk.CzyDrukowacNumeryPowiazanych" }
            }.Select(x => new { bindings = x.Key.DataBindings, binding = new XRBinding("Visible".TranslateIgnore(), null, x.Value) })
            .ToArray()
            , x => x.bindings.Add(x.binding));
        
            GroupHeader1.Visible = GroupHeader2.Visible = d.Korekta;
            detailReportWgCen.Visible = Parametry.WgCen;
            tableRow31.Visible = !string.IsNullOrEmpty(d.Wydruk.ZaplaconoInfo) && !(d.Wydruk.ZaplatyTypy.Count == 1 && d.Wydruk.ZapłataCałkowita);
            detailReportBand15.Visible = !string.IsNullOrEmpty(d.Wydruk.ZaplaconoInfo);
            Grid1Lista.Visible = !Parametry.WgCen;
            sectionNiezaplacone.Visible = d.Wydruk.SąNiezapłacone;
            if (d.Wydruk.ZaliczkaPokrywaCałość)
                label3.Text = "Pozostało do zapłaty 0 {0}".TranslateFormat(d.BruttoCy.Symbol);
            else
                sectionPozostaloDozaplaty.Visible = false;
            sectionWplaty.Visible = !d.Zaliczki.IsEmpty;
            sectionZaliczki.Visible = szVisible;
            SectionKorektaZaliczki.Visible = zaliczka && korekta;
            SectionVAT.Visible =
              d.Definicja.SumyVAT != SposobLiczeniaSumVAT.NieLiczyć &&
            !(zaliczka && !jestMniejszaKwota) && d.Wydruk.NabywcaPodatnik != 1;
            SectionVATZaliczkowego.Visible = zaliczka && !korekta;
            SectionVATZamowienia.Visible = końcowy;
            sectionDoZaplaty.Visible = !zaliczka;
            TabelaVatZaliczkiNapis.Visible = zaliczka && !końcowy;
        
            SectionRozrachunki.Visible = d.Wydruk.RozrachunkiKontrahentaVisible;
            SectionRozrachunkiNapis.Visible = d.Definicja.DrukujPlatnosci && !SectionRozrachunki.Visible;
        
            sectionPowiazaneDokumentyMagazynowe.Visible = false;
            if (d.Definicja.DrukowanieZestawieniaMagazynowych)
            {
                var magazynowe = d.Wydruk.DokumentyPowiazane(d, false, true, TypRelacjiHandlowej.HandlowoMagazynowa)
                    .Concat(d.Wydruk.DokumentyPowiazane(d, false, false, TypRelacjiHandlowej.HandlowoMagazynowa));
                if (magazynowe.Count() != 0)
                {
                    sectionPowiazaneDokumentyMagazynowe.Visible = true;
                    Grid_Magazynowe.DataSource = magazynowe;
                }
            }
        
            ResumeLayout();
        }
        
        void NiezaplaconeInfo_GetValue(object sender, GetValueEventArgs e)
        {
            var p = (WydrukDokumentu.NiezapłaconeInfo)e.Row;
            var d = (DokumentHandlowy)p.Płatność.Dokument;
        
            if (Equals(sender, fdSposobZaplaty) && p.Płatność.SposobZaplaty.Typ == TypySposobowZaplaty.Przelew
                && (p.Płatność.EwidencjaSP.Rachunek != d.RachunekBankowy.Rachunek || d.Platnosci.Count > 1))
            {
                e.Value = string.Join(Environment.NewLine,
                        "{0} na rachunek bankowy: ".TranslateFormat(p.Płatność.SposobZaplaty),
                        p.Płatność.EwidencjaSP.Rachunek.Numer.ToString());
            }
            else if (Equals(sender, fdSposobZaplaty))
            {
                e.Value = p.Płatność.SposobZaplaty;
            }
            else if (Equals(sender, fdPlatnik) && d.InnyPłatnik)
            {
                e.Value = new StringBuilder(p.Płatność.Podmiot.Nazwa)
                    .AppendLine().Append(p.Płatność.Podmiot.Adres)
                    .Append("NIP: ".Translate()).Append(p.Płatność.Podmiot.EuVAT);
            }
        }
        
        void Zaliczki_GetValue(object sender, GetValueEventArgs e)
        {
            var z = (DokumentHandlowy)e.Row;   //FZAl
            DokumentHandlowy d = (DokumentHandlowy)GetCurrentRow();  //FV
            SubTable st = d.ZaliczkiRelacje;
            {
                Currency v = new Currency(decimal.Zero, z.BruttoCy.Symbol);
                foreach (RelacjaHandlowa.Zaliczka rz in st)
                {
                    if (rz.Nadrzedny == z)
                    {
                        v += rz.Wartosc;
                    }
                }
                e.Value = v;
            }
        }
        
        void SetCaption(object sender, PrintEventArgs _)
        {
            var d = GetCurrentRow() as DokumentHandlowy;
            _tableCell25.Text = d != null && d.OdBrutto
                ? "Wartość brutto".Translate()
                : "Wartość netto".Translate();
        }
        
        private void tableCell133_EvaluateBinding(object sender, DevExpress.XtraReports.UI.BindingEventArgs e)
        {
        
            var expectedWord = e.Value as string;
        
            if (expectedWord != null)
                e.Value = " " + expectedWord.Translate();
        }
        
        
        
        void MyBeforePrint(object _, PrintEventArgs __)
        {
            var d = (DokumentHandlowy)GetCurrentRow();
            Stopka.PrintAdditionalText = d.Definicja.InformacjeKRS;
        }
        
        
        private void pozBezOc_GetValue(object sender, DevExpress.XtraReports.UI.GetValueEventArgs e) {
            
            var pozycja = e.Row as PozycjaDokHandlowego;
            
            e.Value = Soneta.OplataCukrowa.
            OplataCukrowaModule.GetInstance(Parametry.Context.Session).
            OpCukrPozDok.GetOplataCukrowaPozycjaDokHandlowego(pozycja).
            CenaBezOC;
        }
        
        // Report Script End

        private void InitializeEvents() {
            DataSourceRowChanged += Sprzedaz_DataSourceRowChanged;
            BeforePrint += MyBeforePrint;
            pozBezOc.GetValue += pozBezOc_GetValue;
            fdZaliczka.GetValue += Zaliczki_GetValue;
            fdPlatnik.GetValue += NiezaplaconeInfo_GetValue;
            fdSposobZaplaty.GetValue += NiezaplaconeInfo_GetValue;
            niezapłaconeLista.BeforePrint += HideColumns;
            Grid_SumyVatLista.BeforePrint += HideColumns;
            detailReportWgCen.BeforePrint += HideColumns;
            SectionVATZaliczkowego.BeforePrint += HideColumns;
            SectionVATZamowienia.BeforePrint += HideColumns;
            Grid1Lista.BeforePrint += HideColumns;
            Dokument.BeforePrint += SetCaption;
        }

        #region Report definition

        private DevExpress.XtraReports.UI.TopMarginBand topMarginBand1;
        private DevExpress.XtraReports.UI.DetailBand Raport;
        private DevExpress.XtraReports.UI.BottomMarginBand bottomMarginBand1;
        private DevExpress.XtraReports.UI.DetailReportBand Dokument;
        private DevExpress.XtraReports.UI.DetailBand DokumentTreść;
        private DevExpress.XtraReports.UI.GroupFooterBand StopkaDokumentu;
        private Soneta.Business.UI.DxReports.Controls.Footer Stopka;
        private DevExpress.XtraReports.UI.DetailReportBand Grid1Lista;
        private DevExpress.XtraReports.UI.DetailBand Grid1ListaWiersz;
        private DevExpress.XtraReports.UI.XRTable table36;
        private DevExpress.XtraReports.UI.XRTableRow tableRow2;
        private DevExpress.XtraReports.UI.XRTableCell tableCell3;
        private DevExpress.XtraReports.UI.XRTable table1;
        private DevExpress.XtraReports.UI.XRTableRow tableRow1;
        private DevExpress.XtraReports.UI.XRTableCell tableCell1;
        private DevExpress.XtraReports.UI.XRTableCell tableCell2;
        private DevExpress.XtraReports.UI.XRTableCell _pozycjeIlosc;
        private DevExpress.XtraReports.UI.XRTableCell _pozycjeIloscSym;
        private DevExpress.XtraReports.UI.XRTableCell _grid1CenaPrzedRabatem;
        private DevExpress.XtraReports.UI.XRTableCell _grid1RabatP;
        private DevExpress.XtraReports.UI.XRTableCell tableCell24;
        private DevExpress.XtraReports.UI.XRTableCell tableCell22;
        private DevExpress.XtraReports.UI.XRTableCell _grid1CenaNettoPoRabacie;
        private DevExpress.XtraReports.UI.XRTableCell _grid1CenaBruttoPoRabacie;
        private DevExpress.XtraReports.UI.XRTableCell wartosc;
        private DevExpress.XtraReports.UI.XRTableCell vat;
        private DevExpress.XtraReports.UI.XRTableCell _sww;
        private DevExpress.XtraReports.UI.XRTableCell _rodzajKorektyCol;
        private DevExpress.XtraReports.UI.GroupHeaderBand Grid1ListaNagłówek;
        private DevExpress.XtraReports.UI.XRTable table3;
        private DevExpress.XtraReports.UI.XRTableRow tableRow4;
        private DevExpress.XtraReports.UI.XRTableCell tableCell17;
        private DevExpress.XtraReports.UI.XRTableCell tableCell18;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell19;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell20;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell21;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell22;
        private DevExpress.XtraReports.UI.XRTableCell tableCell21;
        private DevExpress.XtraReports.UI.XRTableCell tableCell20;
        private DevExpress.XtraReports.UI.XRTableCell tableCell23;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell24;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell25;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell26;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell28;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell29;
        private DevExpress.XtraReports.UI.GroupHeaderBand GroupHeader1;
        private DevExpress.XtraReports.UI.XRTable table32;
        private DevExpress.XtraReports.UI.XRTableRow tableRow33;
        private DevExpress.XtraReports.UI.XRTableCell tableCell145;
        private Soneta.Business.UI.DxReports.BusinessDataSource BusinessSource;
        private DevExpress.XtraReports.UI.DetailReportBand SectionVATZamowienia;
        private DevExpress.XtraReports.UI.DetailBand DetailBand10;
        private DevExpress.XtraReports.UI.XRTable table4;
        private DevExpress.XtraReports.UI.XRTableRow tableRow6;
        private DevExpress.XtraReports.UI.XRTableCell tableCell43;
        private DevExpress.XtraReports.UI.XRTableCell Grid_VATZamowienia_NettoCy;
        private DevExpress.XtraReports.UI.XRTableCell tableCell44;
        private DevExpress.XtraReports.UI.XRTableCell tableCell45;
        private DevExpress.XtraReports.UI.GroupFooterBand GroupFooter10;
        private DevExpress.XtraReports.UI.XRTable table6;
        private DevExpress.XtraReports.UI.XRTableRow tableRow8;
        private DevExpress.XtraReports.UI.XRTableCell tableCell50;
        private DevExpress.XtraReports.UI.XRTableCell tableCell51;
        private DevExpress.XtraReports.UI.XRTableCell tableCell52;
        private DevExpress.XtraReports.UI.XRTableCell tableCell53;
        private DevExpress.XtraReports.UI.XRLabel label13;
        private DevExpress.XtraReports.UI.XRTable table25;
        private DevExpress.XtraReports.UI.XRTableRow tableRow27;
        private DevExpress.XtraReports.UI.XRTableCell tableCell127;
        private DevExpress.XtraReports.UI.XRTableCell tableCell128;
        private DevExpress.XtraReports.UI.XRTableRow tableRow28;
        private DevExpress.XtraReports.UI.XRTableCell tableCell16;
        private DevExpress.XtraReports.UI.XRTableCell tableCell40;
        private DevExpress.XtraReports.UI.GroupHeaderBand GroupHeader10;
        private DevExpress.XtraReports.UI.XRTable table5;
        private DevExpress.XtraReports.UI.XRTableRow tableRow7;
        private DevExpress.XtraReports.UI.XRTableCell tableCell46;
        private DevExpress.XtraReports.UI.XRTableCell tableCell47;
        private DevExpress.XtraReports.UI.XRTableCell tableCell48;
        private DevExpress.XtraReports.UI.XRTableCell tableCell49;
        private DevExpress.XtraReports.UI.DetailReportBand SectionVATZaliczkowego;
        private DevExpress.XtraReports.UI.DetailBand DetailBand15;
        private DevExpress.XtraReports.UI.XRTable table7;
        private DevExpress.XtraReports.UI.XRTableRow tableRow9;
        private DevExpress.XtraReports.UI.XRTableCell tableCell54;
        private DevExpress.XtraReports.UI.XRTableCell Grid_VATZaliczkowego_NettoCy;
        private DevExpress.XtraReports.UI.XRTableCell tableCell55;
        private DevExpress.XtraReports.UI.XRTableCell tableCell56;
        private DevExpress.XtraReports.UI.GroupHeaderBand GroupHeader15;
        private DevExpress.XtraReports.UI.XRTable table8;
        private DevExpress.XtraReports.UI.XRTableRow tableRow10;
        private DevExpress.XtraReports.UI.XRTableCell tableCell57;
        private DevExpress.XtraReports.UI.XRTableCell tableCell58;
        private DevExpress.XtraReports.UI.XRTableCell tableCell59;
        private DevExpress.XtraReports.UI.XRTableCell tableCell60;
        private DevExpress.XtraReports.UI.GroupFooterBand GroupFooter15;
        private DevExpress.XtraReports.UI.XRTable table9;
        private DevExpress.XtraReports.UI.XRTableRow tableRow11;
        private DevExpress.XtraReports.UI.XRTableCell tableCell61;
        private DevExpress.XtraReports.UI.XRTableCell tableCell62;
        private DevExpress.XtraReports.UI.XRTableCell tableCell63;
        private DevExpress.XtraReports.UI.XRTableCell tableCell64;
        private DevExpress.XtraReports.UI.XRLabel label15;
        private DevExpress.XtraReports.UI.XRTable table26;
        private DevExpress.XtraReports.UI.XRTableRow tableRow29;
        private DevExpress.XtraReports.UI.XRTableCell tableCell129;
        private DevExpress.XtraReports.UI.XRTableCell tableCell130;
        private DevExpress.XtraReports.UI.XRTableRow tableRow30;
        private DevExpress.XtraReports.UI.XRTableCell tableCell131;
        private DevExpress.XtraReports.UI.XRTableCell tableCell132;
        private DevExpress.XtraReports.UI.DetailReportBand SectionVAT;
        private DevExpress.XtraReports.UI.DetailBand detailBand9;
        private DevExpress.XtraReports.UI.DetailReportBand Grid_SumyVatLista;
        private DevExpress.XtraReports.UI.DetailBand Grid_SumyVatListaWiersz;
        private DevExpress.XtraReports.UI.XRTable table10;
        private DevExpress.XtraReports.UI.XRTableRow tableRow12;
        private DevExpress.XtraReports.UI.XRTableCell tableCell65;
        private DevExpress.XtraReports.UI.XRTableCell Grid_SumyVat_NettoCy;
        private DevExpress.XtraReports.UI.XRTableCell tableCell66;
        private DevExpress.XtraReports.UI.XRTableCell tableCell5;
        private DevExpress.XtraReports.UI.XRTableCell tableCell67;
        private DevExpress.XtraReports.UI.GroupHeaderBand Grid_SumyVatListaNagłówek;
        private DevExpress.XtraReports.UI.XRTable table11;
        private DevExpress.XtraReports.UI.XRTableRow tableRow13;
        private DevExpress.XtraReports.UI.XRTableCell tableCell68;
        private DevExpress.XtraReports.UI.XRTableCell tableCell69;
        private DevExpress.XtraReports.UI.XRTableCell tableCell70;
        private DevExpress.XtraReports.UI.XRTableCell tableCell19;
        private DevExpress.XtraReports.UI.XRTableCell tableCell71;
        private DevExpress.XtraReports.UI.GroupFooterBand Grid_SumyVatListaStopka;
        private DevExpress.XtraReports.UI.XRLabel TabelaVatZaliczkiNapis;
        private DevExpress.XtraReports.UI.XRTable table12;
        private DevExpress.XtraReports.UI.XRTableRow tableRow14;
        private DevExpress.XtraReports.UI.XRTableCell tableCell72;
        private DevExpress.XtraReports.UI.XRTableCell tableCell73;
        private DevExpress.XtraReports.UI.XRTableCell tableCell74;
        private DevExpress.XtraReports.UI.XRTableCell tableCell15;
        private DevExpress.XtraReports.UI.XRTableCell tableCell75;
        private DevExpress.XtraReports.UI.DetailReportBand SectionKorektaZaliczki;
        private DevExpress.XtraReports.UI.DetailBand Detail;
        private DevExpress.XtraReports.UI.XRTable table2;
        private DevExpress.XtraReports.UI.XRTableRow tableRow3;
        private DevExpress.XtraReports.UI.XRTableCell tableCell13;
        private DevExpress.XtraReports.UI.XRTableCell tableCell27;
        private DevExpress.XtraReports.UI.DetailReportBand sectionZaliczki;
        private DevExpress.XtraReports.UI.DetailBand DetailBand20;
        private DevExpress.XtraReports.UI.XRTable table13;
        private DevExpress.XtraReports.UI.XRTableRow tableRow15;
        private DevExpress.XtraReports.UI.XRTableCell tableCell76;
        private DevExpress.XtraReports.UI.XRTableCell tableCell77;
        private DevExpress.XtraReports.UI.XRTableCell tableCell78;
        private DevExpress.XtraReports.UI.XRTableCell tableCell79;
        private DevExpress.XtraReports.UI.XRTableCell colZaliczka;
        private DevExpress.XtraReports.UI.GroupHeaderBand GroupHeader20;
        private DevExpress.XtraReports.UI.XRTable table14;
        private DevExpress.XtraReports.UI.XRTableRow tableRow16;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell80;
        private DevExpress.XtraReports.UI.XRTableCell tableCell81;
        private DevExpress.XtraReports.UI.XRTableCell tableCell82;
        private DevExpress.XtraReports.UI.XRTableCell tableCell83;
        private DevExpress.XtraReports.UI.XRTableCell tableCell84;
        private DevExpress.XtraReports.UI.XRLabel label20;
        private DevExpress.XtraReports.UI.GroupFooterBand GroupFooter20;
        private DevExpress.XtraReports.UI.XRTable table15;
        private DevExpress.XtraReports.UI.XRTableRow tableRow17;
        private DevExpress.XtraReports.UI.XRTableCell tableCell85;
        private DevExpress.XtraReports.UI.XRTableCell tableCell86;
        private DevExpress.XtraReports.UI.XRTableCell tableCell87;
        private DevExpress.XtraReports.UI.XRTableCell tableCell88;
        private DevExpress.XtraReports.UI.XRTableCell tableCell89;
        private DevExpress.XtraReports.UI.DetailReportBand sectionDoZaplaty;
        private DevExpress.XtraReports.UI.DetailBand detailBand13;
        private DevExpress.XtraReports.UI.XRTable table29;
        private DevExpress.XtraReports.UI.XRTableRow tableRow35;
        private DevExpress.XtraReports.UI.XRTableCell tableCell136;
        private DevExpress.XtraReports.UI.XRTableCell tableCell137;
        private DevExpress.XtraReports.UI.XRTableRow tableRow36;
        private DevExpress.XtraReports.UI.XRTableCell tableCell139;
        private DevExpress.XtraReports.UI.XRTableCell tableCell140;
        private DevExpress.XtraReports.UI.XRTableRow tableRow31;
        private DevExpress.XtraReports.UI.XRTableCell tableCell4;
        private DevExpress.XtraReports.UI.XRTableCell tableCell138;
        private DevExpress.XtraReports.UI.DetailReportBand sectionWplaty;
        private DevExpress.XtraReports.UI.DetailBand detailBand14;
        private DevExpress.XtraReports.UI.XRLabel label21;
        private DevExpress.XtraReports.UI.DetailReportBand Grid2Lista;
        private DevExpress.XtraReports.UI.DetailBand Grid2ListaWiersz;
        private DevExpress.XtraReports.UI.XRTable table16;
        private DevExpress.XtraReports.UI.XRTableRow tableRow18;
        private DevExpress.XtraReports.UI.XRTableCell tableCell90;
        private DevExpress.XtraReports.UI.XRTableCell tableCell91;
        private DevExpress.XtraReports.UI.XRTableCell tableCell92;
        private DevExpress.XtraReports.UI.XRTableCell tableCell93;
        private DevExpress.XtraReports.UI.XRTableCell tableCell94;
        private DevExpress.XtraReports.UI.GroupHeaderBand Grid2ListaNagłówek;
        private DevExpress.XtraReports.UI.XRTable table17;
        private DevExpress.XtraReports.UI.XRTableRow tableRow19;
        private DevExpress.XtraReports.UI.XRTableCell tableCell95;
        private DevExpress.XtraReports.UI.XRTableCell tableCell96;
        private DevExpress.XtraReports.UI.XRTableCell tableCell97;
        private DevExpress.XtraReports.UI.XRTableCell tableCell98;
        private DevExpress.XtraReports.UI.XRTableCell tableCell99;
        private Soneta.Business.UI.DxReports.BusinessDataSource BusinessSourceContext;
        private DevExpress.XtraReports.UI.DetailReportBand sectionNiezaplacone;
        private DevExpress.XtraReports.UI.DetailBand detailBand16;
        private DevExpress.XtraReports.UI.XRLabel label1;
        private DevExpress.XtraReports.UI.DetailReportBand niezapłaconeLista;
        private DevExpress.XtraReports.UI.DetailBand niezapłaconeListaWiersz;
        private DevExpress.XtraReports.UI.XRTable table18;
        private DevExpress.XtraReports.UI.XRTableRow tableRow20;
        private DevExpress.XtraReports.UI.XRTableCell SposobZaplaty;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell101;
        private DevExpress.XtraReports.UI.XRTableCell tableCell102;
        private DevExpress.XtraReports.UI.XRTableCell platnik;
        private DevExpress.XtraReports.UI.GroupHeaderBand niezapłaconeListaNagłówek;
        private DevExpress.XtraReports.UI.XRTable table19;
        private DevExpress.XtraReports.UI.XRTableRow tableRow21;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell104;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell105;
        private DevExpress.XtraReports.UI.XRTableCell tableCell106;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell107;
        private DevExpress.XtraReports.UI.DetailReportBand detailReportBand15;
        private DevExpress.XtraReports.UI.DetailBand detailBand18;
        private DevExpress.XtraReports.UI.XRLabel label2;
        private DevExpress.XtraReports.UI.DetailReportBand sectionPowiazaneDokumentyMagazynowe;
        private DevExpress.XtraReports.UI.DetailBand detailBand19;
        private DevExpress.XtraReports.UI.XRLabel label25;
        private DevExpress.XtraReports.UI.DetailReportBand Grid_Magazynowe;
        private DevExpress.XtraReports.UI.DetailBand Grid_MagazynoweListaWiersz;
        private DevExpress.XtraReports.UI.XRTable table20;
        private DevExpress.XtraReports.UI.XRTableRow tableRow22;
        private DevExpress.XtraReports.UI.XRTableCell MagNumerCol;
        private DevExpress.XtraReports.UI.XRTableCell MagDataCol;
        private DevExpress.XtraReports.UI.XRTableCell MagDataDostawyCol;
        private DevExpress.XtraReports.UI.XRTableCell MagWartCol;
        private DevExpress.XtraReports.UI.GroupHeaderBand Grid_MagazynoweListaNagłówek;
        private DevExpress.XtraReports.UI.XRTable table21;
        private DevExpress.XtraReports.UI.XRTableRow tableRow23;
        private DevExpress.XtraReports.UI.XRTableCell tableCell108;
        private DevExpress.XtraReports.UI.XRTableCell tableCell109;
        private DevExpress.XtraReports.UI.XRTableCell tableCell110;
        private DevExpress.XtraReports.UI.XRTableCell tableCell111;
        private DevExpress.XtraReports.UI.DetailReportBand detailReportWgCen;
        private DevExpress.XtraReports.UI.DetailBand Detail1;
        private DevExpress.XtraReports.UI.XRTable table27;
        private DevExpress.XtraReports.UI.XRTableRow tableRow32;
        private DevExpress.XtraReports.UI.XRTableCell tableCell150;
        private DevExpress.XtraReports.UI.XRTable table35;
        private DevExpress.XtraReports.UI.XRTableRow tableRow44;
        private DevExpress.XtraReports.UI.XRTableCell tableCell171;
        private DevExpress.XtraReports.UI.XRTableCell tableCell172;
        private DevExpress.XtraReports.UI.XRTableCell tableCell173;
        private DevExpress.XtraReports.UI.XRTableCell tableCell174;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell176;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell177;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell178;
        private DevExpress.XtraReports.UI.XRTableCell tableCell179;
        private DevExpress.XtraReports.UI.XRTableCell tableCell180;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell181;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell182;
        private DevExpress.XtraReports.UI.GroupHeaderBand GroupHeader2;
        private DevExpress.XtraReports.UI.XRTable table34;
        private DevExpress.XtraReports.UI.XRTableRow tableRow43;
        private DevExpress.XtraReports.UI.XRTableCell tableCell170;
        private DevExpress.XtraReports.UI.GroupHeaderBand GroupHeader4;
        private DevExpress.XtraReports.UI.XRTable table33;
        private DevExpress.XtraReports.UI.XRTableRow tableRow41;
        private DevExpress.XtraReports.UI.XRTableCell tableCell146;
        private DevExpress.XtraReports.UI.XRTableCell tableCell147;
        private DevExpress.XtraReports.UI.XRTableCell tableCell148;
        private DevExpress.XtraReports.UI.XRTableCell tableCell149;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell151;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell152;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell153;
        private DevExpress.XtraReports.UI.XRTableCell tableCell154;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell155;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell156;
        private DevExpress.XtraReports.UI.XRTableCell _tableCell157;
        private DevExpress.XtraReports.UI.XRTableRow tableRow42;
        private DevExpress.XtraReports.UI.XRTableCell tableCell158;
        private DevExpress.XtraReports.UI.XRTableCell tableCell159;
        private DevExpress.XtraReports.UI.XRTableCell tableCell160;
        private DevExpress.XtraReports.UI.XRTableCell tableCell161;
        private DevExpress.XtraReports.UI.XRTableCell tableCell163;
        private DevExpress.XtraReports.UI.XRTableCell tableCell164;
        private DevExpress.XtraReports.UI.XRTableCell tableCell165;
        private DevExpress.XtraReports.UI.XRTableCell tableCell166;
        private DevExpress.XtraReports.UI.XRTableCell tableCell167;
        private DevExpress.XtraReports.UI.XRTableCell tableCell168;
        private DevExpress.XtraReports.UI.XRTableCell tableCell169;
        private DevExpress.XtraReports.UI.DetailReportBand DetailReport;
        private DevExpress.XtraReports.UI.DetailBand Detail4;
        private DevExpress.XtraReports.UI.XRTable table37;
        private DevExpress.XtraReports.UI.XRTableRow tr_DokumentyPowiazane1;
        private DevExpress.XtraReports.UI.XRTableCell tableCell6;
        private DevExpress.XtraReports.UI.XRTableCell tableCell7;
        private DevExpress.XtraReports.UI.XRTableRow tr_DokumentyPowiazane2;
        private DevExpress.XtraReports.UI.XRTableCell tableCell8;
        private DevExpress.XtraReports.UI.XRTableCell tableCell9;
        private DevExpress.XtraReports.UI.XRTableRow tr_PoprzednieKorekty;
        private DevExpress.XtraReports.UI.XRTableCell tableCell10;
        private DevExpress.XtraReports.UI.XRTableCell tableCell11;
        private DevExpress.XtraReports.UI.XRTableRow tr_OpisDok;
        private DevExpress.XtraReports.UI.XRTableCell tableCell12;
        private DevExpress.XtraReports.UI.XRTableRow tr_OpisWydr;
        private DevExpress.XtraReports.UI.XRTableCell tableCell14;
        private Soneta.Business.UI.DxReports.Controls.DatabaseSubReport databaseSubReport2;
        private DevExpress.XtraReports.UI.DetailReportBand SectionRozrachunki;
        private DevExpress.XtraReports.UI.DetailBand detailBand21;
        private DevExpress.XtraReports.UI.XRPageBreak pageBreak1;
        private DevExpress.XtraReports.UI.XRLabel label26;
        private DevExpress.XtraReports.UI.DetailReportBand GridRozrachunkiLista;
        private DevExpress.XtraReports.UI.DetailBand GridRozrachunkiListaWiersz;
        private DevExpress.XtraReports.UI.XRTable table22;
        private DevExpress.XtraReports.UI.XRTableRow tableRow24;
        private DevExpress.XtraReports.UI.XRTableCell tableCell112;
        private DevExpress.XtraReports.UI.XRTableCell tableCell113;
        private DevExpress.XtraReports.UI.XRTableCell tableCell114;
        private DevExpress.XtraReports.UI.XRTableCell tableCell115;
        private DevExpress.XtraReports.UI.XRTableCell tableCell116;
        private DevExpress.XtraReports.UI.GroupHeaderBand GridRozrachunkiListaNagłówek;
        private DevExpress.XtraReports.UI.XRTable table23;
        private DevExpress.XtraReports.UI.XRTableRow tableRow25;
        private DevExpress.XtraReports.UI.XRTableCell tableCell117;
        private DevExpress.XtraReports.UI.XRTableCell tableCell118;
        private DevExpress.XtraReports.UI.XRTableCell tableCell119;
        private DevExpress.XtraReports.UI.XRTableCell tableCell120;
        private DevExpress.XtraReports.UI.XRTableCell tableCell121;
        private DevExpress.XtraReports.UI.GroupFooterBand GridRozrachunkiListaStopka;
        private DevExpress.XtraReports.UI.XRTable table24;
        private DevExpress.XtraReports.UI.XRTableRow tableRow26;
        private DevExpress.XtraReports.UI.XRTableCell tableCell122;
        private DevExpress.XtraReports.UI.XRTableCell tableCell123;
        private DevExpress.XtraReports.UI.XRTableCell tableCell124;
        private DevExpress.XtraReports.UI.XRTableCell tableCell125;
        private DevExpress.XtraReports.UI.XRTableCell tableCell126;
        private DevExpress.XtraReports.UI.GroupHeaderBand GroupHeader3;
        private Soneta.Business.UI.DxReports.Controls.DatabaseSubReport databaseSubReport1;
        private Soneta.Business.UI.DxReports.Controls.Header required_invisible_header;
        private DevExpress.XtraReports.UI.DetailReportBand sectionPozostaloDozaplaty;
        private DevExpress.XtraReports.UI.DetailBand Detail2;
        private DevExpress.XtraReports.UI.XRLabel label3;
        private DevExpress.XtraReports.UI.DetailReportBand SectionRozrachunkiNapis;
        private DevExpress.XtraReports.UI.DetailBand Detail5;
        private DevExpress.XtraReports.UI.XRPageBreak pageBreak2;
        private DevExpress.XtraReports.UI.XRLabel WykazNierozliczonychNależności;
        private DevExpress.XtraReports.UI.CalculatedField fdSposobZaplaty;
        private DevExpress.XtraReports.UI.CalculatedField fdPlatnik;
        private DevExpress.XtraReports.UI.CalculatedField fdZaliczka;
        private DevExpress.XtraReports.UI.CalculatedField fdSekcjaDokumentu1;
        private DevExpress.XtraReports.UI.CalculatedField fdPrzyczynaZmiany1;
        private DevExpress.XtraReports.UI.CalculatedField pozBezOc;
        private Soneta.Business.UI.DxReports.Components.BusinessContext BusinessContext;
        private System.Resources.ResourceManager _resources;
        public Sprzedaz() {
            this.InitializeComponent();
            this.InitializeEvents();
        }
        private System.Resources.ResourceManager resources {
            get {
                if (_resources == null) {
                    this._resources = new DevExpress.XtraReports.Serialization.XRResourceManager("zsrvvgEAAACRAAAAbFN5c3RlbS5SZXNvdXJjZXMuUmVzb3VyY2VSZWFkZXIsIG1zY29ybGliLCBWZXJzaW9uPTQuMC4wLjAsIEN1bHR1cmU9bmV1dHJhbCwgUHVibGljS2V5VG9rZW49Yjc3YTVjNTYxOTM0ZTA4OSNTeXN0ZW0uUmVzb3VyY2VzLlJ1bnRpbWVSZXNvdXJjZVNldAIAAAAAAAAAAAAAAFBBRFBBRFC0AAAA");
                }
                return this._resources;
            }
        }
        private void InitializeComponent() {
            DevExpress.XtraReports.UI.XRSummary summary1 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary2 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary3 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary4 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary5 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary6 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary7 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary8 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary9 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary10 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary11 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary12 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary13 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary14 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary15 = new DevExpress.XtraReports.UI.XRSummary();
            DevExpress.XtraReports.UI.XRSummary summary16 = new DevExpress.XtraReports.UI.XRSummary();
            this.topMarginBand1 = new DevExpress.XtraReports.UI.TopMarginBand();
            this.Raport = new DevExpress.XtraReports.UI.DetailBand();
            this.bottomMarginBand1 = new DevExpress.XtraReports.UI.BottomMarginBand();
            this.Dokument = new DevExpress.XtraReports.UI.DetailReportBand();
            this.DokumentTreść = new DevExpress.XtraReports.UI.DetailBand();
            this.StopkaDokumentu = new DevExpress.XtraReports.UI.GroupFooterBand();
            this.Grid1Lista = new DevExpress.XtraReports.UI.DetailReportBand();
            this.SectionVATZamowienia = new DevExpress.XtraReports.UI.DetailReportBand();
            this.SectionVATZaliczkowego = new DevExpress.XtraReports.UI.DetailReportBand();
            this.SectionVAT = new DevExpress.XtraReports.UI.DetailReportBand();
            this.sectionZaliczki = new DevExpress.XtraReports.UI.DetailReportBand();
            this.sectionDoZaplaty = new DevExpress.XtraReports.UI.DetailReportBand();
            this.sectionWplaty = new DevExpress.XtraReports.UI.DetailReportBand();
            this.sectionNiezaplacone = new DevExpress.XtraReports.UI.DetailReportBand();
            this.detailReportBand15 = new DevExpress.XtraReports.UI.DetailReportBand();
            this.sectionPowiazaneDokumentyMagazynowe = new DevExpress.XtraReports.UI.DetailReportBand();
            this.detailReportWgCen = new DevExpress.XtraReports.UI.DetailReportBand();
            this.DetailReport = new DevExpress.XtraReports.UI.DetailReportBand();
            this.SectionRozrachunki = new DevExpress.XtraReports.UI.DetailReportBand();
            this.GroupHeader3 = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.sectionPozostaloDozaplaty = new DevExpress.XtraReports.UI.DetailReportBand();
            this.SectionRozrachunkiNapis = new DevExpress.XtraReports.UI.DetailReportBand();
            this.Stopka = new Soneta.Business.UI.DxReports.Controls.Footer();
            this.Grid1ListaWiersz = new DevExpress.XtraReports.UI.DetailBand();
            this.Grid1ListaNagłówek = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.GroupHeader1 = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.table36 = new DevExpress.XtraReports.UI.XRTable();
            this.table1 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow2 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell3 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableRow1 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell1 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell2 = new DevExpress.XtraReports.UI.XRTableCell();
            this._pozycjeIlosc = new DevExpress.XtraReports.UI.XRTableCell();
            this._pozycjeIloscSym = new DevExpress.XtraReports.UI.XRTableCell();
            this._grid1CenaPrzedRabatem = new DevExpress.XtraReports.UI.XRTableCell();
            this._grid1RabatP = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell24 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell22 = new DevExpress.XtraReports.UI.XRTableCell();
            this._grid1CenaNettoPoRabacie = new DevExpress.XtraReports.UI.XRTableCell();
            this._grid1CenaBruttoPoRabacie = new DevExpress.XtraReports.UI.XRTableCell();
            this.wartosc = new DevExpress.XtraReports.UI.XRTableCell();
            this.vat = new DevExpress.XtraReports.UI.XRTableCell();
            this._sww = new DevExpress.XtraReports.UI.XRTableCell();
            this._rodzajKorektyCol = new DevExpress.XtraReports.UI.XRTableCell();
            this.table3 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow4 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell17 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell18 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell19 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell20 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell21 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell22 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell21 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell20 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell23 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell24 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell25 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell26 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell28 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell29 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table32 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow33 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell145 = new DevExpress.XtraReports.UI.XRTableCell();
            this.DetailBand10 = new DevExpress.XtraReports.UI.DetailBand();
            this.GroupFooter10 = new DevExpress.XtraReports.UI.GroupFooterBand();
            this.GroupHeader10 = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.table4 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow6 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell43 = new DevExpress.XtraReports.UI.XRTableCell();
            this.Grid_VATZamowienia_NettoCy = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell44 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell45 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table6 = new DevExpress.XtraReports.UI.XRTable();
            this.label13 = new DevExpress.XtraReports.UI.XRLabel();
            this.table25 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow8 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell50 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell51 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell52 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell53 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableRow27 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableRow28 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell127 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell128 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell16 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell40 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table5 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow7 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell46 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell47 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell48 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell49 = new DevExpress.XtraReports.UI.XRTableCell();
            this.DetailBand15 = new DevExpress.XtraReports.UI.DetailBand();
            this.GroupHeader15 = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.GroupFooter15 = new DevExpress.XtraReports.UI.GroupFooterBand();
            this.table7 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow9 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell54 = new DevExpress.XtraReports.UI.XRTableCell();
            this.Grid_VATZaliczkowego_NettoCy = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell55 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell56 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table8 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow10 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell57 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell58 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell59 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell60 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table9 = new DevExpress.XtraReports.UI.XRTable();
            this.label15 = new DevExpress.XtraReports.UI.XRLabel();
            this.table26 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow11 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell61 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell62 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell63 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell64 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableRow29 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableRow30 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell129 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell130 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell131 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell132 = new DevExpress.XtraReports.UI.XRTableCell();
            this.detailBand9 = new DevExpress.XtraReports.UI.DetailBand();
            this.Grid_SumyVatLista = new DevExpress.XtraReports.UI.DetailReportBand();
            this.SectionKorektaZaliczki = new DevExpress.XtraReports.UI.DetailReportBand();
            this.Grid_SumyVatListaWiersz = new DevExpress.XtraReports.UI.DetailBand();
            this.Grid_SumyVatListaNagłówek = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.Grid_SumyVatListaStopka = new DevExpress.XtraReports.UI.GroupFooterBand();
            this.table10 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow12 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell65 = new DevExpress.XtraReports.UI.XRTableCell();
            this.Grid_SumyVat_NettoCy = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell66 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell5 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell67 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table11 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow13 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell68 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell69 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell70 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell19 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell71 = new DevExpress.XtraReports.UI.XRTableCell();
            this.TabelaVatZaliczkiNapis = new DevExpress.XtraReports.UI.XRLabel();
            this.table12 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow14 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell72 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell73 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell74 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell15 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell75 = new DevExpress.XtraReports.UI.XRTableCell();
            this.Detail = new DevExpress.XtraReports.UI.DetailBand();
            this.table2 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow3 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell13 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell27 = new DevExpress.XtraReports.UI.XRTableCell();
            this.DetailBand20 = new DevExpress.XtraReports.UI.DetailBand();
            this.GroupHeader20 = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.GroupFooter20 = new DevExpress.XtraReports.UI.GroupFooterBand();
            this.table13 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow15 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell76 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell77 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell78 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell79 = new DevExpress.XtraReports.UI.XRTableCell();
            this.colZaliczka = new DevExpress.XtraReports.UI.XRTableCell();
            this.table14 = new DevExpress.XtraReports.UI.XRTable();
            this.label20 = new DevExpress.XtraReports.UI.XRLabel();
            this.tableRow16 = new DevExpress.XtraReports.UI.XRTableRow();
            this._tableCell80 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell81 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell82 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell83 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell84 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table15 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow17 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell85 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell86 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell87 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell88 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell89 = new DevExpress.XtraReports.UI.XRTableCell();
            this.detailBand13 = new DevExpress.XtraReports.UI.DetailBand();
            this.table29 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow35 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableRow36 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableRow31 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell136 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell137 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell139 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell140 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell4 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell138 = new DevExpress.XtraReports.UI.XRTableCell();
            this.detailBand14 = new DevExpress.XtraReports.UI.DetailBand();
            this.Grid2Lista = new DevExpress.XtraReports.UI.DetailReportBand();
            this.label21 = new DevExpress.XtraReports.UI.XRLabel();
            this.Grid2ListaWiersz = new DevExpress.XtraReports.UI.DetailBand();
            this.Grid2ListaNagłówek = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.table16 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow18 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell90 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell91 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell92 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell93 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell94 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table17 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow19 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell95 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell96 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell97 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell98 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell99 = new DevExpress.XtraReports.UI.XRTableCell();
            this.detailBand16 = new DevExpress.XtraReports.UI.DetailBand();
            this.niezapłaconeLista = new DevExpress.XtraReports.UI.DetailReportBand();
            this.label1 = new DevExpress.XtraReports.UI.XRLabel();
            this.niezapłaconeListaWiersz = new DevExpress.XtraReports.UI.DetailBand();
            this.niezapłaconeListaNagłówek = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.table18 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow20 = new DevExpress.XtraReports.UI.XRTableRow();
            this.SposobZaplaty = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell101 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell102 = new DevExpress.XtraReports.UI.XRTableCell();
            this.platnik = new DevExpress.XtraReports.UI.XRTableCell();
            this.table19 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow21 = new DevExpress.XtraReports.UI.XRTableRow();
            this._tableCell104 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell105 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell106 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell107 = new DevExpress.XtraReports.UI.XRTableCell();
            this.detailBand18 = new DevExpress.XtraReports.UI.DetailBand();
            this.label2 = new DevExpress.XtraReports.UI.XRLabel();
            this.detailBand19 = new DevExpress.XtraReports.UI.DetailBand();
            this.Grid_Magazynowe = new DevExpress.XtraReports.UI.DetailReportBand();
            this.label25 = new DevExpress.XtraReports.UI.XRLabel();
            this.Grid_MagazynoweListaWiersz = new DevExpress.XtraReports.UI.DetailBand();
            this.Grid_MagazynoweListaNagłówek = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.table20 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow22 = new DevExpress.XtraReports.UI.XRTableRow();
            this.MagNumerCol = new DevExpress.XtraReports.UI.XRTableCell();
            this.MagDataCol = new DevExpress.XtraReports.UI.XRTableCell();
            this.MagDataDostawyCol = new DevExpress.XtraReports.UI.XRTableCell();
            this.MagWartCol = new DevExpress.XtraReports.UI.XRTableCell();
            this.table21 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow23 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell108 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell109 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell110 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell111 = new DevExpress.XtraReports.UI.XRTableCell();
            this.Detail1 = new DevExpress.XtraReports.UI.DetailBand();
            this.GroupHeader2 = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.GroupHeader4 = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.table27 = new DevExpress.XtraReports.UI.XRTable();
            this.table35 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow32 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell150 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableRow44 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell171 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell172 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell173 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell174 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell176 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell177 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell178 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell179 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell180 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell181 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell182 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table34 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow43 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell170 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table33 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow41 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableRow42 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell146 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell147 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell148 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell149 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell151 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell152 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell153 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell154 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell155 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell156 = new DevExpress.XtraReports.UI.XRTableCell();
            this._tableCell157 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell158 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell159 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell160 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell161 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell163 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell164 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell165 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell166 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell167 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell168 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell169 = new DevExpress.XtraReports.UI.XRTableCell();
            this.Detail4 = new DevExpress.XtraReports.UI.DetailBand();
            this.table37 = new DevExpress.XtraReports.UI.XRTable();
            this.databaseSubReport2 = new Soneta.Business.UI.DxReports.Controls.DatabaseSubReport();
            this.tr_DokumentyPowiazane1 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tr_DokumentyPowiazane2 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tr_PoprzednieKorekty = new DevExpress.XtraReports.UI.XRTableRow();
            this.tr_OpisDok = new DevExpress.XtraReports.UI.XRTableRow();
            this.tr_OpisWydr = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell6 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell7 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell8 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell9 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell10 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell11 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell12 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell14 = new DevExpress.XtraReports.UI.XRTableCell();
            this.detailBand21 = new DevExpress.XtraReports.UI.DetailBand();
            this.GridRozrachunkiLista = new DevExpress.XtraReports.UI.DetailReportBand();
            this.pageBreak1 = new DevExpress.XtraReports.UI.XRPageBreak();
            this.label26 = new DevExpress.XtraReports.UI.XRLabel();
            this.GridRozrachunkiListaWiersz = new DevExpress.XtraReports.UI.DetailBand();
            this.GridRozrachunkiListaNagłówek = new DevExpress.XtraReports.UI.GroupHeaderBand();
            this.GridRozrachunkiListaStopka = new DevExpress.XtraReports.UI.GroupFooterBand();
            this.table22 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow24 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell112 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell113 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell114 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell115 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell116 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table23 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow25 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell117 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell118 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell119 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell120 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell121 = new DevExpress.XtraReports.UI.XRTableCell();
            this.table24 = new DevExpress.XtraReports.UI.XRTable();
            this.tableRow26 = new DevExpress.XtraReports.UI.XRTableRow();
            this.tableCell122 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell123 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell124 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell125 = new DevExpress.XtraReports.UI.XRTableCell();
            this.tableCell126 = new DevExpress.XtraReports.UI.XRTableCell();
            this.databaseSubReport1 = new Soneta.Business.UI.DxReports.Controls.DatabaseSubReport();
            this.required_invisible_header = new Soneta.Business.UI.DxReports.Controls.Header();
            this.Detail2 = new DevExpress.XtraReports.UI.DetailBand();
            this.label3 = new DevExpress.XtraReports.UI.XRLabel();
            this.Detail5 = new DevExpress.XtraReports.UI.DetailBand();
            this.pageBreak2 = new DevExpress.XtraReports.UI.XRPageBreak();
            this.WykazNierozliczonychNależności = new DevExpress.XtraReports.UI.XRLabel();
            this.fdSposobZaplaty = new DevExpress.XtraReports.UI.CalculatedField();
            this.fdPlatnik = new DevExpress.XtraReports.UI.CalculatedField();
            this.fdZaliczka = new DevExpress.XtraReports.UI.CalculatedField();
            this.fdSekcjaDokumentu1 = new DevExpress.XtraReports.UI.CalculatedField();
            this.fdPrzyczynaZmiany1 = new DevExpress.XtraReports.UI.CalculatedField();
            this.pozBezOc = new DevExpress.XtraReports.UI.CalculatedField();
            this.BusinessContext = new Soneta.Business.UI.DxReports.Components.BusinessContext();
            this.BusinessSource = new Soneta.Business.UI.DxReports.BusinessDataSource();
            this.BusinessSourceContext = new Soneta.Business.UI.DxReports.BusinessDataSource();
            ((System.ComponentModel.ISupportInitialize)(this.table36)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table3)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table32)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table4)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table6)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table25)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table5)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table7)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table8)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table9)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table26)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table10)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table11)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table12)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table2)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table13)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table14)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table15)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table29)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table16)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table17)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table18)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table19)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table20)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table21)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table27)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table35)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table34)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table33)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table37)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table22)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table23)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.table24)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this)).BeginInit();
            // 
            // topMarginBand1
            // 
            this.topMarginBand1.Dpi = 254F;
            this.topMarginBand1.HeightF = 200F;
            this.topMarginBand1.Name = "topMarginBand1";
            // 
            // Raport
            // 
            this.Raport.Dpi = 254F;
            this.Raport.HeightF = 0F;
            this.Raport.KeepTogether = true;
            this.Raport.KeepTogetherWithDetailReports = true;
            this.Raport.Name = "Raport";
            this.Raport.Visible = false;
            // 
            // bottomMarginBand1
            // 
            this.bottomMarginBand1.Dpi = 254F;
            this.bottomMarginBand1.HeightF = 200F;
            this.bottomMarginBand1.Name = "bottomMarginBand1";
            // 
            // Dokument
            // 
            this.Dokument.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.DokumentTreść,
                        this.StopkaDokumentu,
                        this.Grid1Lista,
                        this.SectionVATZamowienia,
                        this.SectionVATZaliczkowego,
                        this.SectionVAT,
                        this.sectionZaliczki,
                        this.sectionDoZaplaty,
                        this.sectionWplaty,
                        this.sectionNiezaplacone,
                        this.detailReportBand15,
                        this.sectionPowiazaneDokumentyMagazynowe,
                        this.detailReportWgCen,
                        this.DetailReport,
                        this.SectionRozrachunki,
                        this.GroupHeader3,
                        this.sectionPozostaloDozaplaty,
                        this.SectionRozrachunkiNapis});
            this.Dokument.DataMember = "This";
            this.Dokument.DataSource = this.BusinessSource;
            this.Dokument.Dpi = 254F;
            this.Dokument.Level = 0;
            this.Dokument.Name = "Dokument";
            // 
            // DokumentTreść
            // 
            this.DokumentTreść.Dpi = 254F;
            this.DokumentTreść.HeightF = 0F;
            this.DokumentTreść.Name = "DokumentTreść";
            // 
            // StopkaDokumentu
            // 
            this.StopkaDokumentu.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.Stopka});
            this.StopkaDokumentu.Dpi = 254F;
            this.StopkaDokumentu.HeightF = 50F;
            this.StopkaDokumentu.Name = "StopkaDokumentu";
            this.StopkaDokumentu.PageBreak = DevExpress.XtraReports.UI.PageBreak.AfterBand;
            this.StopkaDokumentu.RepeatEveryPage = true;
            // 
            // Grid1Lista
            // 
            this.Grid1Lista.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Grid1ListaWiersz,
                        this.Grid1ListaNagłówek,
                        this.GroupHeader1});
            this.Grid1Lista.DataMember = "Wydruk.PozycjeRazem";
            this.Grid1Lista.DataSource = this.BusinessSource;
            this.Grid1Lista.Dpi = 254F;
            this.Grid1Lista.Level = 1;
            this.Grid1Lista.Name = "Grid1Lista";
            // 
            // SectionVATZamowienia
            // 
            this.SectionVATZamowienia.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.DetailBand10,
                        this.GroupFooter10,
                        this.GroupHeader10});
            this.SectionVATZamowienia.DataMember = "Workers.DokumentZaliczkowy.TabelaVAT";
            this.SectionVATZamowienia.DataSource = this.BusinessSource;
            this.SectionVATZamowienia.Dpi = 254F;
            this.SectionVATZamowienia.Level = 2;
            this.SectionVATZamowienia.Name = "SectionVATZamowienia";
            // 
            // SectionVATZaliczkowego
            // 
            this.SectionVATZaliczkowego.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.DetailBand15,
                        this.GroupHeader15,
                        this.GroupFooter15});
            this.SectionVATZaliczkowego.DataMember = "Workers.DokumentZaliczkowy.TabelaVAT";
            this.SectionVATZaliczkowego.DataSource = this.BusinessSource;
            this.SectionVATZaliczkowego.Dpi = 254F;
            this.SectionVATZaliczkowego.Expanded = false;
            this.SectionVATZaliczkowego.Level = 3;
            this.SectionVATZaliczkowego.Name = "SectionVATZaliczkowego";
            // 
            // SectionVAT
            // 
            this.SectionVAT.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.detailBand9,
                        this.Grid_SumyVatLista,
                        this.SectionKorektaZaliczki});
            this.SectionVAT.Dpi = 254F;
            this.SectionVAT.Expanded = false;
            this.SectionVAT.Level = 4;
            this.SectionVAT.Name = "SectionVAT";
            // 
            // sectionZaliczki
            // 
            this.sectionZaliczki.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.DetailBand20,
                        this.GroupHeader20,
                        this.GroupFooter20});
            this.sectionZaliczki.DataMember = "Wydruk.DokumentyZaliczkowe";
            this.sectionZaliczki.DataSource = this.BusinessSource;
            this.sectionZaliczki.Dpi = 254F;
            this.sectionZaliczki.Expanded = false;
            this.sectionZaliczki.Level = 5;
            this.sectionZaliczki.Name = "sectionZaliczki";
            // 
            // sectionDoZaplaty
            // 
            this.sectionDoZaplaty.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.detailBand13});
            this.sectionDoZaplaty.Dpi = 254F;
            this.sectionDoZaplaty.Expanded = false;
            this.sectionDoZaplaty.Level = 6;
            this.sectionDoZaplaty.Name = "sectionDoZaplaty";
            // 
            // sectionWplaty
            // 
            this.sectionWplaty.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.detailBand14,
                        this.Grid2Lista});
            this.sectionWplaty.DataMember = "This";
            this.sectionWplaty.DataSource = this.BusinessSourceContext;
            this.sectionWplaty.Dpi = 254F;
            this.sectionWplaty.Expanded = false;
            this.sectionWplaty.Level = 7;
            this.sectionWplaty.Name = "sectionWplaty";
            // 
            // sectionNiezaplacone
            // 
            this.sectionNiezaplacone.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.detailBand16,
                        this.niezapłaconeLista});
            this.sectionNiezaplacone.Dpi = 254F;
            this.sectionNiezaplacone.Expanded = false;
            this.sectionNiezaplacone.Level = 8;
            this.sectionNiezaplacone.Name = "sectionNiezaplacone";
            // 
            // detailReportBand15
            // 
            this.detailReportBand15.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.detailBand18});
            this.detailReportBand15.Dpi = 254F;
            this.detailReportBand15.Expanded = false;
            this.detailReportBand15.Level = 10;
            this.detailReportBand15.Name = "detailReportBand15";
            // 
            // sectionPowiazaneDokumentyMagazynowe
            // 
            this.sectionPowiazaneDokumentyMagazynowe.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.detailBand19,
                        this.Grid_Magazynowe});
            this.sectionPowiazaneDokumentyMagazynowe.Dpi = 254F;
            this.sectionPowiazaneDokumentyMagazynowe.Expanded = false;
            this.sectionPowiazaneDokumentyMagazynowe.Level = 11;
            this.sectionPowiazaneDokumentyMagazynowe.Name = "sectionPowiazaneDokumentyMagazynowe";
            // 
            // detailReportWgCen
            // 
            this.detailReportWgCen.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Detail1,
                        this.GroupHeader2,
                        this.GroupHeader4});
            this.detailReportWgCen.DataMember = "ScriptingReport+MyParametryWydruku.PozycjeRazemWgTowaruICenyZKorektami";
            this.detailReportWgCen.DataSource = this.BusinessSourceContext;
            this.detailReportWgCen.Dpi = 254F;
            this.detailReportWgCen.Expanded = false;
            this.detailReportWgCen.Level = 0;
            this.detailReportWgCen.Name = "detailReportWgCen";
            // 
            // DetailReport
            // 
            this.DetailReport.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Detail4});
            this.DetailReport.Dpi = 254F;
            this.DetailReport.Expanded = false;
            this.DetailReport.Level = 12;
            this.DetailReport.Name = "DetailReport";
            // 
            // SectionRozrachunki
            // 
            this.SectionRozrachunki.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.detailBand21,
                        this.GridRozrachunkiLista});
            this.SectionRozrachunki.Dpi = 254F;
            this.SectionRozrachunki.Expanded = false;
            this.SectionRozrachunki.Level = 13;
            this.SectionRozrachunki.Name = "SectionRozrachunki";
            // 
            // GroupHeader3
            // 
            this.GroupHeader3.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.databaseSubReport1,
                        this.required_invisible_header});
            this.GroupHeader3.Dpi = 254F;
            this.GroupHeader3.Expanded = false;
            this.GroupHeader3.HeightF = 117.8399F;
            this.GroupHeader3.Name = "GroupHeader3";
            this.GroupHeader3.RepeatEveryPage = true;
            // 
            // sectionPozostaloDozaplaty
            // 
            this.sectionPozostaloDozaplaty.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Detail2});
            this.sectionPozostaloDozaplaty.DataMember = "This.This";
            this.sectionPozostaloDozaplaty.DataSource = this.BusinessSource;
            this.sectionPozostaloDozaplaty.Dpi = 254F;
            this.sectionPozostaloDozaplaty.Expanded = false;
            this.sectionPozostaloDozaplaty.Level = 9;
            this.sectionPozostaloDozaplaty.Name = "sectionPozostaloDozaplaty";
            // 
            // SectionRozrachunkiNapis
            // 
            this.SectionRozrachunkiNapis.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Detail5});
            this.SectionRozrachunkiNapis.Dpi = 254F;
            this.SectionRozrachunkiNapis.Expanded = false;
            this.SectionRozrachunkiNapis.Level = 14;
            this.SectionRozrachunkiNapis.Name = "SectionRozrachunkiNapis";
            // 
            // Stopka
            // 
            this.Stopka.Dpi = 254F;
            this.Stopka.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.Stopka.Name = "Stopka";
            this.Stopka.ReportSourceName = "stopka";
            this.Stopka.RunningBand = "Dokument";
            this.Stopka.SizeF = new System.Drawing.SizeF(1701.8F, 50F);
            // 
            // Grid1ListaWiersz
            // 
            this.Grid1ListaWiersz.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table36,
                        this.table1});
            this.Grid1ListaWiersz.Dpi = 254F;
            this.Grid1ListaWiersz.HeightF = 76.19998F;
            this.Grid1ListaWiersz.KeepTogether = true;
            this.Grid1ListaWiersz.Name = "Grid1ListaWiersz";
            this.Grid1ListaWiersz.SortFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("Dokument", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending),
                        new DevExpress.XtraReports.UI.GroupField("Lp", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending)});
            this.Grid1ListaWiersz.StyleName = "ListaStylAutomatyczny";
            // 
            // Grid1ListaNagłówek
            // 
            this.Grid1ListaNagłówek.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table3});
            this.Grid1ListaNagłówek.Dpi = 254F;
            this.Grid1ListaNagłówek.HeightF = 38.1F;
            this.Grid1ListaNagłówek.KeepTogether = true;
            this.Grid1ListaNagłówek.Level = 1;
            this.Grid1ListaNagłówek.Name = "Grid1ListaNagłówek";
            this.Grid1ListaNagłówek.RepeatEveryPage = true;
            this.Grid1ListaNagłówek.StyleName = "ListaStylAutomatyczny";
            // 
            // GroupHeader1
            // 
            this.GroupHeader1.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table32});
            this.GroupHeader1.Dpi = 254F;
            this.GroupHeader1.GroupFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("Workers.WydrukPozycji.SekcjaDokumentu", DevExpress.XtraReports.UI.XRColumnSortOrder.Descending)});
            this.GroupHeader1.HeightF = 63.50002F;
            this.GroupHeader1.Name = "GroupHeader1";
            this.GroupHeader1.StyleName = "TekstPomocniczyWyroznienieStyl";
            // 
            // table36
            // 
            this.table36.Dpi = 254F;
            this.table36.LocationFloat = new DevExpress.Utils.PointFloat(0F, 38.09998F);
            this.table36.Name = "table36";
            this.table36.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow2});
            this.table36.SizeF = new System.Drawing.SizeF(1701.8F, 38.1F);
            // 
            // table1
            // 
            this.table1.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table1.Dpi = 254F;
            this.table1.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table1.Name = "table1";
            this.table1.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow1});
            this.table1.SizeF = new System.Drawing.SizeF(1704F, 38.1F);
            this.table1.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow2
            // 
            this.tableRow2.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell3});
            this.tableRow2.Dpi = 254F;
            this.tableRow2.Name = "tableRow2";
            this.tableRow2.Weight = 0.59999925508363372D;
            // 
            // tableCell3
            // 
            this.tableCell3.CanShrink = true;
            this.tableCell3.Dpi = 254F;
            this.tableCell3.Multiline = true;
            this.tableCell3.Name = "tableCell3";
            this.tableCell3.Text = "[NazwaResztaLinii]";
            this.tableCell3.Weight = 1D;
            // 
            // tableRow1
            // 
            this.tableRow1.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell1,
                        this.tableCell2,
                        this._pozycjeIlosc,
                        this._pozycjeIloscSym,
                        this._grid1CenaPrzedRabatem,
                        this._grid1RabatP,
                        this.tableCell24,
                        this.tableCell22,
                        this._grid1CenaNettoPoRabacie,
                        this._grid1CenaBruttoPoRabacie,
                        this.wartosc,
                        this.vat,
                        this._sww,
                        this._rodzajKorektyCol});
            this.tableRow1.Dpi = 254F;
            this.tableRow1.Name = "tableRow1";
            this.tableRow1.Weight = 0.92D;
            // 
            // tableCell1
            // 
            this.tableCell1.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.Lp")});
            this.tableCell1.Dpi = 254F;
            this.tableCell1.Name = "tableCell1";
            this.tableCell1.StylePriority.UseTextAlignment = false;
            this.tableCell1.Text = "Lp.";
            this.tableCell1.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell1.Weight = 0.034912708037010506D;
            // 
            // tableCell2
            // 
            this.tableCell2.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.NazwaPierwszaLinia")});
            this.tableCell2.Dpi = 254F;
            this.tableCell2.Name = "tableCell2";
            this.tableCell2.StylePriority.UseTextAlignment = false;
            this.tableCell2.Text = "Nazwa towaru/usługi";
            this.tableCell2.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell2.Weight = 0.0026794960009207925D;
            // 
            // _pozycjeIlosc
            // 
            this._pozycjeIlosc.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.Ilosc.Value")});
            this._pozycjeIlosc.Dpi = 254F;
            this._pozycjeIlosc.Name = "_pozycjeIlosc";
            this._pozycjeIlosc.StylePriority.UseTextAlignment = false;
            this._pozycjeIlosc.Text = "Ilość";
            this._pozycjeIlosc.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this._pozycjeIlosc.Weight = 0.052112613838505385D;
            // 
            // _pozycjeIloscSym
            // 
            this._pozycjeIloscSym.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.Symbol")});
            this._pozycjeIloscSym.Dpi = 254F;
            this._pozycjeIloscSym.Name = "_pozycjeIloscSym";
            this._pozycjeIloscSym.StylePriority.UseTextAlignment = false;
            this._pozycjeIloscSym.Text = "jm.";
            this._pozycjeIloscSym.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this._pozycjeIloscSym.Weight = 0.035758847334687559D;
            // 
            // _grid1CenaPrzedRabatem
            // 
            this._grid1CenaPrzedRabatem.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.Cena")});
            this._grid1CenaPrzedRabatem.Dpi = 254F;
            this._grid1CenaPrzedRabatem.Name = "_grid1CenaPrzedRabatem";
            this._grid1CenaPrzedRabatem.StylePriority.UseTextAlignment = false;
            this._grid1CenaPrzedRabatem.Text = "Cena przed rabatem";
            this._grid1CenaPrzedRabatem.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this._grid1CenaPrzedRabatem.Weight = 0.084183229362089676D;
            // 
            // _grid1RabatP
            // 
            this._grid1RabatP.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.Rabat")});
            this._grid1RabatP.Dpi = 254F;
            this._grid1RabatP.Name = "_grid1RabatP";
            this._grid1RabatP.StylePriority.UseTextAlignment = false;
            this._grid1RabatP.Text = "Rabat %";
            this._grid1RabatP.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this._grid1RabatP.Weight = 0.062562500478136385D;
            // 
            // tableCell24
            // 
            this.tableCell24.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.pozBezOc")});
            this.tableCell24.Dpi = 254F;
            this.tableCell24.Multiline = true;
            this.tableCell24.Name = "tableCell24";
            this.tableCell24.StylePriority.UseTextAlignment = false;
            this.tableCell24.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell24.Weight = 0.08502172763557983D;
            // 
            // tableCell22
            // 
            this.tableCell22.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.Cena")});
            this.tableCell22.Dpi = 254F;
            this.tableCell22.Multiline = true;
            this.tableCell22.Name = "tableCell22";
            this.tableCell22.StylePriority.UseTextAlignment = false;
            this.tableCell22.Text = "tableCell22";
            this.tableCell22.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell22.Weight = 0.084765683999163718D;
            // 
            // _grid1CenaNettoPoRabacie
            // 
            this._grid1CenaNettoPoRabacie.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.CenaNettoPoRabacie")});
            this._grid1CenaNettoPoRabacie.Dpi = 254F;
            this._grid1CenaNettoPoRabacie.Name = "_grid1CenaNettoPoRabacie";
            this._grid1CenaNettoPoRabacie.StylePriority.UseTextAlignment = false;
            this._grid1CenaNettoPoRabacie.Text = "Cena netto";
            this._grid1CenaNettoPoRabacie.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this._grid1CenaNettoPoRabacie.Weight = 0.084509513616568388D;
            // 
            // _grid1CenaBruttoPoRabacie
            // 
            this._grid1CenaBruttoPoRabacie.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.CenaBruttoPoRabacie")});
            this._grid1CenaBruttoPoRabacie.Dpi = 254F;
            this._grid1CenaBruttoPoRabacie.Name = "_grid1CenaBruttoPoRabacie";
            this._grid1CenaBruttoPoRabacie.Text = "Cena brutto";
            this._grid1CenaBruttoPoRabacie.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this._grid1CenaBruttoPoRabacie.Weight = 0.08655896963403209D;
            // 
            // wartosc
            // 
            this.wartosc.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.WartoscCy")});
            this.wartosc.Dpi = 254F;
            this.wartosc.Name = "wartosc";
            this.wartosc.StylePriority.UseTextAlignment = false;
            this.wartosc.Text = "Wartość netto";
            this.wartosc.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.wartosc.Weight = 0.089956490087997276D;
            // 
            // vat
            // 
            this.vat.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.DefinicjaStawki")});
            this.vat.Dpi = 254F;
            this.vat.Multiline = true;
            this.vat.Name = "vat";
            this.vat.StylePriority.UseTextAlignment = false;
            this.vat.Text = "Stawka\r\nVAT";
            this.vat.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.vat.Weight = 0.054681081637115839D;
            // 
            // _sww
            // 
            this._sww.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.SWW")});
            this._sww.Dpi = 254F;
            this._sww.Name = "_sww";
            this._sww.StylePriority.UseTextAlignment = false;
            this._sww.Text = "PKWiU";
            this._sww.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this._sww.Weight = 0.065483452808295359D;
            // 
            // _rodzajKorektyCol
            // 
            this._rodzajKorektyCol.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.PozycjeRazem.RodzajKorektyOpis")});
            this._rodzajKorektyCol.Dpi = 254F;
            this._rodzajKorektyCol.Multiline = true;
            this._rodzajKorektyCol.Name = "_rodzajKorektyCol";
            this._rodzajKorektyCol.StylePriority.UseTextAlignment = false;
            this._rodzajKorektyCol.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this._rodzajKorektyCol.Weight = 0.089985922643703142D;
            // 
            // table3
            // 
            this.table3.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table3.Dpi = 254F;
            this.table3.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table3.Name = "table3";
            this.table3.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow4});
            this.table3.SizeF = new System.Drawing.SizeF(1704F, 38.1F);
            this.table3.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow4
            // 
            this.tableRow4.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell17,
                        this.tableCell18,
                        this._tableCell19,
                        this._tableCell20,
                        this._tableCell21,
                        this._tableCell22,
                        this.tableCell21,
                        this.tableCell20,
                        this.tableCell23,
                        this._tableCell24,
                        this._tableCell25,
                        this._tableCell26,
                        this._tableCell28,
                        this._tableCell29});
            this.tableRow4.Dpi = 254F;
            this.tableRow4.Name = "tableRow4";
            this.tableRow4.Weight = 0.92D;
            // 
            // tableCell17
            // 
            this.tableCell17.Dpi = 254F;
            this.tableCell17.Name = "tableCell17";
            this.tableCell17.StylePriority.UseTextAlignment = false;
            this.tableCell17.Text = "Lp.";
            this.tableCell17.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell17.Weight = 0.036158975541071947D;
            // 
            // tableCell18
            // 
            this.tableCell18.Dpi = 254F;
            this.tableCell18.Name = "tableCell18";
            this.tableCell18.Text = "Nazwa towaru/usługi";
            this.tableCell18.Weight = 0.0027705943897647668D;
            // 
            // _tableCell19
            // 
            this._tableCell19.Dpi = 254F;
            this._tableCell19.Name = "_tableCell19";
            this._tableCell19.Text = "Ilość";
            this._tableCell19.Weight = 0.054238131932517315D;
            // 
            // _tableCell20
            // 
            this._tableCell20.Dpi = 254F;
            this._tableCell20.Name = "_tableCell20";
            this._tableCell20.Text = "jm.";
            this._tableCell20.Weight = 0.03703529736788029D;
            // 
            // _tableCell21
            // 
            this._tableCell21.Dpi = 254F;
            this._tableCell21.Name = "_tableCell21";
            this._tableCell21.Text = "Cena przed rabatem";
            this._tableCell21.Weight = 0.087188305116591758D;
            // 
            // _tableCell22
            // 
            this._tableCell22.Dpi = 254F;
            this._tableCell22.Name = "_tableCell22";
            this._tableCell22.Text = "Rabat %";
            this._tableCell22.Weight = 0.064795758520994062D;
            // 
            // tableCell21
            // 
            this.tableCell21.Dpi = 254F;
            this.tableCell21.Multiline = true;
            this.tableCell21.Name = "tableCell21";
            this.tableCell21.Text = "Cena netto bez OC";
            this.tableCell21.Weight = 0.087791494040741852D;
            // 
            // tableCell20
            // 
            this.tableCell20.Dpi = 254F;
            this.tableCell20.Multiline = true;
            this.tableCell20.Name = "tableCell20";
            this.tableCell20.Text = "Cena netto z OC";
            this.tableCell20.Weight = 0.087791494040741852D;
            // 
            // tableCell23
            // 
            this.tableCell23.Dpi = 254F;
            this.tableCell23.Name = "tableCell23";
            this.tableCell23.Text = "Cena netto";
            this.tableCell23.Weight = 0.087791494040741852D;
            // 
            // _tableCell24
            // 
            this._tableCell24.Dpi = 254F;
            this._tableCell24.Name = "_tableCell24";
            this._tableCell24.Text = "Cena brutto";
            this._tableCell24.Weight = 0.0896487722829846D;
            // 
            // _tableCell25
            // 
            this._tableCell25.Dpi = 254F;
            this._tableCell25.Name = "_tableCell25";
            this._tableCell25.Text = "Wartość";
            this._tableCell25.Weight = 0.093167701863354033D;
            // 
            // _tableCell26
            // 
            this._tableCell26.Dpi = 254F;
            this._tableCell26.Multiline = true;
            this._tableCell26.Name = "_tableCell26";
            this._tableCell26.Text = "Stawka VAT";
            this._tableCell26.Weight = 0.056632979920859229D;
            // 
            // _tableCell28
            // 
            this._tableCell28.Dpi = 254F;
            this._tableCell28.Name = "_tableCell28";
            this._tableCell28.Text = "PKWiU";
            this._tableCell28.Weight = 0.067820978530368975D;
            // 
            // _tableCell29
            // 
            this._tableCell29.Dpi = 254F;
            this._tableCell29.Multiline = true;
            this._tableCell29.Name = "_tableCell29";
            this._tableCell29.Text = "Zmiana\r\r\n(Przyczyna korekty)";
            this._tableCell29.Weight = 0.092937345896597884D;
            // 
            // table32
            // 
            this.table32.Dpi = 254F;
            this.table32.LocationFloat = new DevExpress.Utils.PointFloat(0F, 23.50002F);
            this.table32.Name = "table32";
            this.table32.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow33});
            this.table32.SizeF = new System.Drawing.SizeF(1704F, 40F);
            // 
            // tableRow33
            // 
            this.tableRow33.Borders = DevExpress.XtraPrinting.BorderSide.Bottom;
            this.tableRow33.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell145});
            this.tableRow33.Dpi = 254F;
            this.tableRow33.Name = "tableRow33";
            this.tableRow33.StylePriority.UseBorders = false;
            this.tableRow33.Weight = 1D;
            // 
            // tableCell145
            // 
            this.tableCell145.BorderColor = System.Drawing.Color.LightGray;
            this.tableCell145.Dpi = 254F;
            this.tableCell145.Name = "tableCell145";
            this.tableCell145.StylePriority.UseBorderColor = false;
            this.tableCell145.StylePriority.UseTextAlignment = false;
            this.tableCell145.Text = "[Workers.WydrukPozycji.SekcjaDokumentu.Format]";
            this.tableCell145.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell145.Weight = 3D;
            // 
            // DetailBand10
            // 
            this.DetailBand10.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table4});
            this.DetailBand10.Dpi = 254F;
            this.DetailBand10.HeightF = 38.1F;
            this.DetailBand10.Name = "DetailBand10";
            this.DetailBand10.SortFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("DefinicjaStawki.WgWielkosci", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending)});
            this.DetailBand10.StyleName = "ListaStylAutomatyczny";
            // 
            // GroupFooter10
            // 
            this.GroupFooter10.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table6,
                        this.label13,
                        this.table25});
            this.GroupFooter10.Dpi = 254F;
            this.GroupFooter10.HeightF = 148.8126F;
            this.GroupFooter10.Name = "GroupFooter10";
            this.GroupFooter10.StyleName = "ListaStylAutomatyczny";
            // 
            // GroupHeader10
            // 
            this.GroupHeader10.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table5});
            this.GroupHeader10.Dpi = 254F;
            this.GroupHeader10.HeightF = 38.1F;
            this.GroupHeader10.Name = "GroupHeader10";
            this.GroupHeader10.StyleName = "ListaStylAutomatyczny";
            // 
            // table4
            // 
            this.table4.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table4.Dpi = 254F;
            this.table4.LocationFloat = new DevExpress.Utils.PointFloat(784.0005F, 0F);
            this.table4.Name = "table4";
            this.table4.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow6});
            this.table4.SizeF = new System.Drawing.SizeF(920F, 38.1F);
            this.table4.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow6
            // 
            this.tableRow6.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell43,
                        this.Grid_VATZamowienia_NettoCy,
                        this.tableCell44,
                        this.tableCell45});
            this.tableRow6.Dpi = 254F;
            this.tableRow6.Name = "tableRow6";
            this.tableRow6.Weight = 11.5D;
            // 
            // tableCell43
            // 
            this.tableCell43.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.DefinicjaStawki")});
            this.tableCell43.Dpi = 254F;
            this.tableCell43.Name = "tableCell43";
            this.tableCell43.StylePriority.UseTextAlignment = false;
            this.tableCell43.Text = "Stawka VAT";
            this.tableCell43.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell43.Weight = 0.049873066801290007D;
            // 
            // Grid_VATZamowienia_NettoCy
            // 
            this.Grid_VATZamowienia_NettoCy.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.NettoCy")});
            this.Grid_VATZamowienia_NettoCy.Dpi = 254F;
            this.Grid_VATZamowienia_NettoCy.Name = "Grid_VATZamowienia_NettoCy";
            this.Grid_VATZamowienia_NettoCy.Text = "Netto";
            this.Grid_VATZamowienia_NettoCy.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.Grid_VATZamowienia_NettoCy.Weight = 0.049873124457489752D;
            // 
            // tableCell44
            // 
            this.tableCell44.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.VATCy", "{0:n}")});
            this.tableCell44.Dpi = 254F;
            this.tableCell44.Name = "tableCell44";
            this.tableCell44.Text = "Kwota VAT";
            this.tableCell44.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell44.Weight = 0.049873051538201908D;
            // 
            // tableCell45
            // 
            this.tableCell45.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.BruttoCy")});
            this.tableCell45.Dpi = 254F;
            this.tableCell45.Name = "tableCell45";
            this.tableCell45.Text = "Brutto";
            this.tableCell45.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell45.Weight = 0.049873074020766406D;
            // 
            // table6
            // 
            this.table6.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table6.Dpi = 254F;
            this.table6.LocationFloat = new DevExpress.Utils.PointFloat(784.0004F, 0F);
            this.table6.Name = "table6";
            this.table6.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow8});
            this.table6.SizeF = new System.Drawing.SizeF(920.0001F, 38.1F);
            this.table6.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // label13
            // 
            this.label13.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.label13.Dpi = 254F;
            this.label13.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.label13.LocationFloat = new DevExpress.Utils.PointFloat(0.06011422F, 0F);
            this.label13.Name = "label13";
            this.label13.SizeF = new System.Drawing.SizeF(767.4033F, 38.10002F);
            this.label13.StyleName = "TekstPodstawowyWyroznienieStyl";
            this.label13.StylePriority.UseFont = false;
            this.label13.StylePriority.UseTextAlignment = false;
            this.label13.Text = "Wartość zamówienia";
            this.label13.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            // 
            // table25
            // 
            this.table25.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.table25.Dpi = 254F;
            this.table25.LocationFloat = new DevExpress.Utils.PointFloat(0.06011422F, 48.81259F);
            this.table25.Name = "table25";
            this.table25.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow27,
                        this.tableRow28});
            this.table25.SizeF = new System.Drawing.SizeF(1319.166F, 100F);
            this.table25.StyleName = "TekstPomocniczyStyl";
            this.table25.StylePriority.UseBorders = false;
            // 
            // tableRow8
            // 
            this.tableRow8.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell50,
                        this.tableCell51,
                        this.tableCell52,
                        this.tableCell53});
            this.tableRow8.Dpi = 254F;
            this.tableRow8.Name = "tableRow8";
            this.tableRow8.Weight = 11.5D;
            // 
            // tableCell50
            // 
            this.tableCell50.Dpi = 254F;
            this.tableCell50.Name = "tableCell50";
            this.tableCell50.Padding = new DevExpress.XtraPrinting.PaddingInfo(0, 20, 0, 0, 254F);
            this.tableCell50.StylePriority.UsePadding = false;
            this.tableCell50.Text = "Razem:";
            this.tableCell50.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell50.Weight = 0.070410073711549614D;
            // 
            // tableCell51
            // 
            this.tableCell51.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.NettoCy")});
            this.tableCell51.Dpi = 254F;
            this.tableCell51.Name = "tableCell51";
            summary1.IgnoreNullValues = true;
            summary1.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell51.Summary = summary1;
            this.tableCell51.Text = "Netto";
            this.tableCell51.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell51.Weight = 0.070410093819517058D;
            // 
            // tableCell52
            // 
            this.tableCell52.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.VATCy")});
            this.tableCell52.Dpi = 254F;
            this.tableCell52.Name = "tableCell52";
            summary2.FormatString = "{0:n}";
            summary2.IgnoreNullValues = true;
            summary2.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell52.Summary = summary2;
            this.tableCell52.Text = "Kwota VAT";
            this.tableCell52.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell52.Weight = 0.0704100879033775D;
            // 
            // tableCell53
            // 
            this.tableCell53.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.BruttoCy")});
            this.tableCell53.Dpi = 254F;
            this.tableCell53.Name = "tableCell53";
            summary3.IgnoreNullValues = true;
            summary3.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell53.Summary = summary3;
            this.tableCell53.Text = "Brutto";
            this.tableCell53.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell53.Weight = 0.07041008465701816D;
            // 
            // tableRow27
            // 
            this.tableRow27.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell127,
                        this.tableCell128});
            this.tableRow27.Dpi = 254F;
            this.tableRow27.Name = "tableRow27";
            this.tableRow27.Weight = 0.78740157480314954D;
            // 
            // tableRow28
            // 
            this.tableRow28.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell16,
                        this.tableCell40});
            this.tableRow28.Dpi = 254F;
            this.tableRow28.Name = "tableRow28";
            this.tableRow28.Weight = 0.78740157480314965D;
            // 
            // tableCell127
            // 
            this.tableCell127.Borders = DevExpress.XtraPrinting.BorderSide.Bottom;
            this.tableCell127.Dpi = 254F;
            this.tableCell127.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell127.Name = "tableCell127";
            this.tableCell127.StylePriority.UseBorders = false;
            this.tableCell127.StylePriority.UseFont = false;
            this.tableCell127.StylePriority.UseTextAlignment = false;
            this.tableCell127.Text = "Podlega opodatkowaniu";
            this.tableCell127.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell127.Weight = 0.69661116830260106D;
            // 
            // tableCell128
            // 
            this.tableCell128.Borders = DevExpress.XtraPrinting.BorderSide.Bottom;
            this.tableCell128.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "BruttoCy")});
            this.tableCell128.Dpi = 254F;
            this.tableCell128.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell128.Name = "tableCell128";
            this.tableCell128.StylePriority.UseBorders = false;
            this.tableCell128.StylePriority.UseFont = false;
            this.tableCell128.StylePriority.UseTextAlignment = false;
            this.tableCell128.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell128.Weight = 1.0622764456296907D;
            // 
            // tableCell16
            // 
            this.tableCell16.Dpi = 254F;
            this.tableCell16.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell16.Name = "tableCell16";
            this.tableCell16.StylePriority.UseFont = false;
            this.tableCell16.StylePriority.UseTextAlignment = false;
            this.tableCell16.Text = "Słownie:";
            this.tableCell16.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell16.Weight = 0.69661116830260106D;
            // 
            // tableCell40
            // 
            this.tableCell40.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "BruttoCy", "{0:+t2}")});
            this.tableCell40.Dpi = 254F;
            this.tableCell40.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell40.Name = "tableCell40";
            this.tableCell40.StylePriority.UseFont = false;
            this.tableCell40.StylePriority.UseTextAlignment = false;
            this.tableCell40.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell40.Weight = 1.0622764456296907D;
            // 
            // table5
            // 
            this.table5.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table5.Dpi = 254F;
            this.table5.LocationFloat = new DevExpress.Utils.PointFloat(784.0004F, 0F);
            this.table5.Name = "table5";
            this.table5.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow7});
            this.table5.SizeF = new System.Drawing.SizeF(920F, 38.1F);
            this.table5.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow7
            // 
            this.tableRow7.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell46,
                        this.tableCell47,
                        this.tableCell48,
                        this.tableCell49});
            this.tableRow7.Dpi = 254F;
            this.tableRow7.Name = "tableRow7";
            this.tableRow7.Weight = 11.5D;
            // 
            // tableCell46
            // 
            this.tableCell46.Dpi = 254F;
            this.tableCell46.Name = "tableCell46";
            this.tableCell46.Text = "Stawka VAT";
            this.tableCell46.Weight = 0.069426384478707789D;
            // 
            // tableCell47
            // 
            this.tableCell47.Dpi = 254F;
            this.tableCell47.Name = "tableCell47";
            this.tableCell47.Text = "Netto";
            this.tableCell47.Weight = 0.069426389076530676D;
            // 
            // tableCell48
            // 
            this.tableCell48.Dpi = 254F;
            this.tableCell48.Name = "tableCell48";
            this.tableCell48.Text = "Kwota VAT";
            this.tableCell48.Weight = 0.069426388773566591D;
            // 
            // tableCell49
            // 
            this.tableCell49.Dpi = 254F;
            this.tableCell49.Name = "tableCell49";
            this.tableCell49.Text = "Brutto";
            this.tableCell49.Weight = 0.0694263838768032D;
            // 
            // DetailBand15
            // 
            this.DetailBand15.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table7});
            this.DetailBand15.Dpi = 254F;
            this.DetailBand15.HeightF = 38.1F;
            this.DetailBand15.Name = "DetailBand15";
            this.DetailBand15.SortFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("DefinicjaStawki.WgWielkosci", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending)});
            this.DetailBand15.StyleName = "ListaStylAutomatyczny";
            // 
            // GroupHeader15
            // 
            this.GroupHeader15.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table8});
            this.GroupHeader15.Dpi = 254F;
            this.GroupHeader15.HeightF = 63.10001F;
            this.GroupHeader15.Name = "GroupHeader15";
            this.GroupHeader15.StyleName = "ListaStylAutomatyczny";
            // 
            // GroupFooter15
            // 
            this.GroupFooter15.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table9,
                        this.label15,
                        this.table26});
            this.GroupFooter15.Dpi = 254F;
            this.GroupFooter15.HeightF = 167.3334F;
            this.GroupFooter15.Name = "GroupFooter15";
            this.GroupFooter15.StyleName = "ListaStylAutomatyczny";
            // 
            // table7
            // 
            this.table7.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table7.Dpi = 254F;
            this.table7.LocationFloat = new DevExpress.Utils.PointFloat(784.0004F, 0F);
            this.table7.Name = "table7";
            this.table7.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow9});
            this.table7.SizeF = new System.Drawing.SizeF(920F, 38.1F);
            this.table7.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow9
            // 
            this.tableRow9.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell54,
                        this.Grid_VATZaliczkowego_NettoCy,
                        this.tableCell55,
                        this.tableCell56});
            this.tableRow9.Dpi = 254F;
            this.tableRow9.Name = "tableRow9";
            this.tableRow9.Weight = 11.5D;
            // 
            // tableCell54
            // 
            this.tableCell54.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.DefinicjaStawki")});
            this.tableCell54.Dpi = 254F;
            this.tableCell54.Name = "tableCell54";
            this.tableCell54.StylePriority.UseTextAlignment = false;
            this.tableCell54.Text = "Stawka VAT";
            this.tableCell54.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell54.Weight = 0.069426384604492963D;
            // 
            // Grid_VATZaliczkowego_NettoCy
            // 
            this.Grid_VATZaliczkowego_NettoCy.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.NettoCy")});
            this.Grid_VATZaliczkowego_NettoCy.Dpi = 254F;
            this.Grid_VATZaliczkowego_NettoCy.Name = "Grid_VATZaliczkowego_NettoCy";
            this.Grid_VATZaliczkowego_NettoCy.Text = "Netto";
            this.Grid_VATZaliczkowego_NettoCy.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.Grid_VATZaliczkowego_NettoCy.Weight = 0.069426375259052472D;
            // 
            // tableCell55
            // 
            this.tableCell55.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.VATCy", "{0:n}")});
            this.tableCell55.Dpi = 254F;
            this.tableCell55.Name = "tableCell55";
            this.tableCell55.Text = "Kwota VAT";
            this.tableCell55.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell55.Weight = 0.069426374784970074D;
            // 
            // tableCell56
            // 
            this.tableCell56.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.BruttoCy")});
            this.tableCell56.Dpi = 254F;
            this.tableCell56.Name = "tableCell56";
            this.tableCell56.Text = "Brutto";
            this.tableCell56.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell56.Weight = 0.069426383871839026D;
            // 
            // table8
            // 
            this.table8.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table8.Dpi = 254F;
            this.table8.LocationFloat = new DevExpress.Utils.PointFloat(784.0005F, 25.00001F);
            this.table8.Name = "table8";
            this.table8.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow10});
            this.table8.SizeF = new System.Drawing.SizeF(920F, 38.1F);
            this.table8.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow10
            // 
            this.tableRow10.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell57,
                        this.tableCell58,
                        this.tableCell59,
                        this.tableCell60});
            this.tableRow10.Dpi = 254F;
            this.tableRow10.Name = "tableRow10";
            this.tableRow10.Weight = 11.5D;
            // 
            // tableCell57
            // 
            this.tableCell57.Dpi = 254F;
            this.tableCell57.Name = "tableCell57";
            this.tableCell57.Text = "Stawka VAT";
            this.tableCell57.Weight = 0.069426381696368056D;
            // 
            // tableCell58
            // 
            this.tableCell58.Dpi = 254F;
            this.tableCell58.Name = "tableCell58";
            this.tableCell58.Text = "Netto";
            this.tableCell58.Weight = 0.069426375271503443D;
            // 
            // tableCell59
            // 
            this.tableCell59.Dpi = 254F;
            this.tableCell59.Name = "tableCell59";
            this.tableCell59.Text = "Kwota VAT";
            this.tableCell59.Weight = 0.069426374679763148D;
            // 
            // tableCell60
            // 
            this.tableCell60.Dpi = 254F;
            this.tableCell60.Name = "tableCell60";
            this.tableCell60.Text = "Brutto";
            this.tableCell60.Weight = 0.069426365465980244D;
            // 
            // table9
            // 
            this.table9.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table9.Dpi = 254F;
            this.table9.LocationFloat = new DevExpress.Utils.PointFloat(784.0005F, 0F);
            this.table9.Name = "table9";
            this.table9.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow11});
            this.table9.SizeF = new System.Drawing.SizeF(920F, 38.1F);
            this.table9.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // label15
            // 
            this.label15.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.label15.Dpi = 254F;
            this.label15.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.label15.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.label15.Multiline = true;
            this.label15.Name = "label15";
            this.label15.SizeF = new System.Drawing.SizeF(754.7034F, 38.10002F);
            this.label15.StyleName = "TekstPodstawowyWyroznienieStyl";
            this.label15.StylePriority.UseFont = false;
            this.label15.StylePriority.UseTextAlignment = false;
            this.label15.Text = "Wartość zamówienia";
            this.label15.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            // 
            // table26
            // 
            this.table26.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.table26.Dpi = 254F;
            this.table26.LocationFloat = new DevExpress.Utils.PointFloat(0.06007385F, 67.33342F);
            this.table26.Name = "table26";
            this.table26.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow29,
                        this.tableRow30});
            this.table26.SizeF = new System.Drawing.SizeF(1319.166F, 100F);
            this.table26.StyleName = "TekstPomocniczyStyl";
            this.table26.StylePriority.UseBorders = false;
            // 
            // tableRow11
            // 
            this.tableRow11.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell61,
                        this.tableCell62,
                        this.tableCell63,
                        this.tableCell64});
            this.tableRow11.Dpi = 254F;
            this.tableRow11.Name = "tableRow11";
            this.tableRow11.Weight = 11.5D;
            // 
            // tableCell61
            // 
            this.tableCell61.Dpi = 254F;
            this.tableCell61.Name = "tableCell61";
            this.tableCell61.Padding = new DevExpress.XtraPrinting.PaddingInfo(0, 20, 0, 0, 254F);
            this.tableCell61.StylePriority.UsePadding = false;
            this.tableCell61.Text = "Razem:";
            this.tableCell61.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell61.Weight = 0.069426375598880138D;
            // 
            // tableCell62
            // 
            this.tableCell62.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.NettoCy")});
            this.tableCell62.Dpi = 254F;
            this.tableCell62.Name = "tableCell62";
            summary4.IgnoreNullValues = true;
            summary4.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell62.Summary = summary4;
            this.tableCell62.Text = "Netto";
            this.tableCell62.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell62.Weight = 0.069426375257297654D;
            // 
            // tableCell63
            // 
            this.tableCell63.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.VATCy")});
            this.tableCell63.Dpi = 254F;
            this.tableCell63.Name = "tableCell63";
            summary5.FormatString = "{0:n}";
            summary5.IgnoreNullValues = true;
            summary5.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell63.Summary = summary5;
            this.tableCell63.Text = "Kwota VAT";
            this.tableCell63.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell63.Weight = 0.069426374630868426D;
            // 
            // tableCell64
            // 
            this.tableCell64.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Workers.DokumentZaliczkowy.TabelaVAT.Suma.BruttoCy")});
            this.tableCell64.Dpi = 254F;
            this.tableCell64.Name = "tableCell64";
            summary6.IgnoreNullValues = true;
            summary6.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell64.Summary = summary6;
            this.tableCell64.Text = "Brutto";
            this.tableCell64.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell64.Weight = 0.069426365450993968D;
            // 
            // tableRow29
            // 
            this.tableRow29.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell129,
                        this.tableCell130});
            this.tableRow29.Dpi = 254F;
            this.tableRow29.Name = "tableRow29";
            this.tableRow29.Weight = 1D;
            // 
            // tableRow30
            // 
            this.tableRow30.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell131,
                        this.tableCell132});
            this.tableRow30.Dpi = 254F;
            this.tableRow30.Name = "tableRow30";
            this.tableRow30.Weight = 1D;
            // 
            // tableCell129
            // 
            this.tableCell129.Borders = DevExpress.XtraPrinting.BorderSide.Bottom;
            this.tableCell129.Dpi = 254F;
            this.tableCell129.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell129.Name = "tableCell129";
            this.tableCell129.StylePriority.UseBorders = false;
            this.tableCell129.StylePriority.UseFont = false;
            this.tableCell129.StylePriority.UseTextAlignment = false;
            this.tableCell129.Text = "Kwota zaliczki";
            this.tableCell129.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell129.Weight = 0.51179870701486874D;
            // 
            // tableCell130
            // 
            this.tableCell130.Borders = DevExpress.XtraPrinting.BorderSide.Bottom;
            this.tableCell130.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "BruttoCy")});
            this.tableCell130.Dpi = 254F;
            this.tableCell130.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell130.Name = "tableCell130";
            this.tableCell130.StylePriority.UseBorders = false;
            this.tableCell130.StylePriority.UseFont = false;
            this.tableCell130.StylePriority.UseTextAlignment = false;
            this.tableCell130.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell130.Weight = 1.247089151058048D;
            // 
            // tableCell131
            // 
            this.tableCell131.Dpi = 254F;
            this.tableCell131.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell131.Name = "tableCell131";
            this.tableCell131.StylePriority.UseFont = false;
            this.tableCell131.StylePriority.UseTextAlignment = false;
            this.tableCell131.Text = "Słownie:";
            this.tableCell131.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell131.Weight = 0.51179870701486874D;
            // 
            // tableCell132
            // 
            this.tableCell132.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "BruttoCy", "{0:+t2}")});
            this.tableCell132.Dpi = 254F;
            this.tableCell132.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell132.Name = "tableCell132";
            this.tableCell132.StylePriority.UseFont = false;
            this.tableCell132.StylePriority.UseTextAlignment = false;
            this.tableCell132.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell132.Weight = 1.247089151058048D;
            // 
            // detailBand9
            // 
            this.detailBand9.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.detailBand9.Dpi = 254F;
            this.detailBand9.HeightF = 0F;
            this.detailBand9.Name = "detailBand9";
            this.detailBand9.StyleName = "ListaNaglowekStyl";
            this.detailBand9.StylePriority.UseBorders = false;
            // 
            // Grid_SumyVatLista
            // 
            this.Grid_SumyVatLista.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Grid_SumyVatListaWiersz,
                        this.Grid_SumyVatListaNagłówek,
                        this.Grid_SumyVatListaStopka});
            this.Grid_SumyVatLista.DataMember = "This.SumyVAT";
            this.Grid_SumyVatLista.DataSource = this.BusinessSource;
            this.Grid_SumyVatLista.Dpi = 254F;
            this.Grid_SumyVatLista.Level = 1;
            this.Grid_SumyVatLista.Name = "Grid_SumyVatLista";
            this.Grid_SumyVatLista.ReportPrintOptions.DetailCountOnEmptyDataSource = 0;
            // 
            // SectionKorektaZaliczki
            // 
            this.SectionKorektaZaliczki.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Detail});
            this.SectionKorektaZaliczki.Dpi = 254F;
            this.SectionKorektaZaliczki.Level = 0;
            this.SectionKorektaZaliczki.Name = "SectionKorektaZaliczki";
            // 
            // Grid_SumyVatListaWiersz
            // 
            this.Grid_SumyVatListaWiersz.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table10});
            this.Grid_SumyVatListaWiersz.Dpi = 254F;
            this.Grid_SumyVatListaWiersz.HeightF = 38.1F;
            this.Grid_SumyVatListaWiersz.KeepTogether = true;
            this.Grid_SumyVatListaWiersz.Name = "Grid_SumyVatListaWiersz";
            this.Grid_SumyVatListaWiersz.SortFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending)});
            this.Grid_SumyVatListaWiersz.StyleName = "ListaStylAutomatyczny";
            // 
            // Grid_SumyVatListaNagłówek
            // 
            this.Grid_SumyVatListaNagłówek.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table11});
            this.Grid_SumyVatListaNagłówek.Dpi = 254F;
            this.Grid_SumyVatListaNagłówek.HeightF = 64.55832F;
            this.Grid_SumyVatListaNagłówek.KeepTogether = true;
            this.Grid_SumyVatListaNagłówek.Name = "Grid_SumyVatListaNagłówek";
            this.Grid_SumyVatListaNagłówek.RepeatEveryPage = true;
            this.Grid_SumyVatListaNagłówek.StyleName = "ListaStylAutomatyczny";
            // 
            // Grid_SumyVatListaStopka
            // 
            this.Grid_SumyVatListaStopka.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.TabelaVatZaliczkiNapis,
                        this.table12});
            this.Grid_SumyVatListaStopka.Dpi = 254F;
            this.Grid_SumyVatListaStopka.HeightF = 38.10002F;
            this.Grid_SumyVatListaStopka.KeepTogether = true;
            this.Grid_SumyVatListaStopka.Name = "Grid_SumyVatListaStopka";
            this.Grid_SumyVatListaStopka.StyleName = "ListaStylAutomatyczny";
            // 
            // table10
            // 
            this.table10.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table10.Dpi = 254F;
            this.table10.LocationFloat = new DevExpress.Utils.PointFloat(784.0005F, 0F);
            this.table10.Name = "table10";
            this.table10.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow12});
            this.table10.SizeF = new System.Drawing.SizeF(920F, 38.1F);
            this.table10.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow12
            // 
            this.tableRow12.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell65,
                        this.Grid_SumyVat_NettoCy,
                        this.tableCell66,
                        this.tableCell5,
                        this.tableCell67});
            this.tableRow12.Dpi = 254F;
            this.tableRow12.Name = "tableRow12";
            this.tableRow12.Weight = 11.5D;
            // 
            // tableCell65
            // 
            this.tableCell65.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "This.SumyVAT.DefinicjaStawki.Kod")});
            this.tableCell65.Dpi = 254F;
            this.tableCell65.Name = "tableCell65";
            this.tableCell65.StylePriority.UseTextAlignment = false;
            this.tableCell65.Text = "Stawka VAT";
            this.tableCell65.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell65.Weight = 0.086782901615048841D;
            // 
            // Grid_SumyVat_NettoCy
            // 
            this.Grid_SumyVat_NettoCy.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "This.SumyVAT.Suma.NettoCy")});
            this.Grid_SumyVat_NettoCy.Dpi = 254F;
            this.Grid_SumyVat_NettoCy.Name = "Grid_SumyVat_NettoCy";
            this.Grid_SumyVat_NettoCy.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.Grid_SumyVat_NettoCy.Weight = 0.086783129438591927D;
            // 
            // tableCell66
            // 
            this.tableCell66.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "This.SumyVAT.Suma.VATCy")});
            this.tableCell66.Dpi = 254F;
            this.tableCell66.Name = "tableCell66";
            this.tableCell66.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell66.Weight = 0.034713096069058966D;
            // 
            // tableCell5
            // 
            this.tableCell5.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "This.SumyVAT.Suma.VAT", "{0:n2}")});
            this.tableCell5.Dpi = 254F;
            this.tableCell5.Multiline = true;
            this.tableCell5.Name = "tableCell5";
            this.tableCell5.StylePriority.UseTextAlignment = false;
            this.tableCell5.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell5.Weight = 0.052069781570493412D;
            // 
            // tableCell67
            // 
            this.tableCell67.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "This.SumyVAT.Suma.BruttoCy")});
            this.tableCell67.Dpi = 254F;
            this.tableCell67.Name = "tableCell67";
            this.tableCell67.Text = "Brutto";
            this.tableCell67.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell67.Weight = 0.086782958966123452D;
            // 
            // table11
            // 
            this.table11.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table11.Dpi = 254F;
            this.table11.LocationFloat = new DevExpress.Utils.PointFloat(784.0005F, 25.00001F);
            this.table11.Name = "table11";
            this.table11.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow13});
            this.table11.SizeF = new System.Drawing.SizeF(920F, 38.1F);
            this.table11.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow13
            // 
            this.tableRow13.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell68,
                        this.tableCell69,
                        this.tableCell70,
                        this.tableCell19,
                        this.tableCell71});
            this.tableRow13.Dpi = 254F;
            this.tableRow13.Name = "tableRow13";
            this.tableRow13.Weight = 11.5D;
            // 
            // tableCell68
            // 
            this.tableCell68.Dpi = 254F;
            this.tableCell68.Name = "tableCell68";
            this.tableCell68.Text = "Stawka VAT";
            this.tableCell68.Weight = 0.086782765769912451D;
            // 
            // tableCell69
            // 
            this.tableCell69.Dpi = 254F;
            this.tableCell69.Name = "tableCell69";
            this.tableCell69.Text = "Netto";
            this.tableCell69.Weight = 0.086783278626014454D;
            // 
            // tableCell70
            // 
            this.tableCell70.Dpi = 254F;
            this.tableCell70.Name = "tableCell70";
            this.tableCell70.Text = "Kwota VAT";
            this.tableCell70.Weight = 0.034713042131200023D;
            // 
            // tableCell19
            // 
            this.tableCell19.Dpi = 254F;
            this.tableCell19.Multiline = true;
            this.tableCell19.Name = "tableCell19";
            this.tableCell19.Text = "Kwota VAT";
            this.tableCell19.Weight = 0.052069770325358658D;
            // 
            // tableCell71
            // 
            this.tableCell71.Dpi = 254F;
            this.tableCell71.Name = "tableCell71";
            this.tableCell71.Text = "Brutto";
            this.tableCell71.Weight = 0.0867829434771648D;
            // 
            // TabelaVatZaliczkiNapis
            // 
            this.TabelaVatZaliczkiNapis.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.TabelaVatZaliczkiNapis.Dpi = 254F;
            this.TabelaVatZaliczkiNapis.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.TabelaVatZaliczkiNapis.LocationFloat = new DevExpress.Utils.PointFloat(0.06007385F, 0F);
            this.TabelaVatZaliczkiNapis.Multiline = true;
            this.TabelaVatZaliczkiNapis.Name = "TabelaVatZaliczkiNapis";
            this.TabelaVatZaliczkiNapis.SizeF = new System.Drawing.SizeF(767.3433F, 38.10002F);
            this.TabelaVatZaliczkiNapis.StyleName = "TekstPodstawowyWyroznienieStyl";
            this.TabelaVatZaliczkiNapis.StylePriority.UseFont = false;
            this.TabelaVatZaliczkiNapis.StylePriority.UseTextAlignment = false;
            this.TabelaVatZaliczkiNapis.Text = "Tabela VAT zaliczki";
            this.TabelaVatZaliczkiNapis.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            // 
            // table12
            // 
            this.table12.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table12.Dpi = 254F;
            this.table12.LocationFloat = new DevExpress.Utils.PointFloat(784.0005F, 0F);
            this.table12.Name = "table12";
            this.table12.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow14});
            this.table12.SizeF = new System.Drawing.SizeF(920F, 38.1F);
            this.table12.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow14
            // 
            this.tableRow14.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell72,
                        this.tableCell73,
                        this.tableCell74,
                        this.tableCell15,
                        this.tableCell75});
            this.tableRow14.Dpi = 254F;
            this.tableRow14.Name = "tableRow14";
            this.tableRow14.Weight = 11.5D;
            // 
            // tableCell72
            // 
            this.tableCell72.Dpi = 254F;
            this.tableCell72.Name = "tableCell72";
            this.tableCell72.Padding = new DevExpress.XtraPrinting.PaddingInfo(0, 20, 0, 0, 254F);
            this.tableCell72.StylePriority.UsePadding = false;
            this.tableCell72.Text = "Razem:";
            this.tableCell72.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell72.Weight = 0.086782835692784221D;
            // 
            // tableCell73
            // 
            this.tableCell73.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "This.SumyVAT.Suma.NettoCy")});
            this.tableCell73.Dpi = 254F;
            this.tableCell73.Name = "tableCell73";
            summary7.IgnoreNullValues = true;
            summary7.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell73.Summary = summary7;
            this.tableCell73.Text = "Netto";
            this.tableCell73.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell73.Weight = 0.086783108760261712D;
            // 
            // tableCell74
            // 
            this.tableCell74.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "This.SumyVAT.Suma.VATCy")});
            this.tableCell74.Dpi = 254F;
            this.tableCell74.Name = "tableCell74";
            summary8.IgnoreNullValues = true;
            summary8.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell74.Summary = summary8;
            this.tableCell74.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell74.Weight = 0.0347131313817383D;
            // 
            // tableCell15
            // 
            this.tableCell15.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "This.SumyVAT.Suma.VAT")});
            this.tableCell15.Dpi = 254F;
            this.tableCell15.Multiline = true;
            this.tableCell15.Name = "tableCell15";
            this.tableCell15.StylePriority.UseTextAlignment = false;
            summary9.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell15.Summary = summary9;
            this.tableCell15.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell15.TextFormatString = "{0:n2}";
            this.tableCell15.Weight = 0.052069767449352891D;
            // 
            // tableCell75
            // 
            this.tableCell75.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "This.SumyVAT.Suma.BruttoCy")});
            this.tableCell75.Dpi = 254F;
            this.tableCell75.Name = "tableCell75";
            summary10.IgnoreNullValues = true;
            summary10.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell75.Summary = summary10;
            this.tableCell75.Text = "Brutto";
            this.tableCell75.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell75.Weight = 0.086782956883647441D;
            // 
            // Detail
            // 
            this.Detail.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table2});
            this.Detail.Dpi = 254F;
            this.Detail.HeightF = 63.50002F;
            this.Detail.Name = "Detail";
            this.Detail.StyleName = "TekstPomocniczyWyroznienieStyl";
            // 
            // table2
            // 
            this.table2.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.table2.Dpi = 254F;
            this.table2.LocationFloat = new DevExpress.Utils.PointFloat(0.06007385F, 23.50002F);
            this.table2.Name = "table2";
            this.table2.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow3});
            this.table2.SizeF = new System.Drawing.SizeF(1703.94F, 40F);
            this.table2.StylePriority.UseBorders = false;
            // 
            // tableRow3
            // 
            this.tableRow3.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell13,
                        this.tableCell27});
            this.tableRow3.Dpi = 254F;
            this.tableRow3.Name = "tableRow3";
            this.tableRow3.Weight = 0.62992125984251968D;
            // 
            // tableCell13
            // 
            this.tableCell13.Dpi = 254F;
            this.tableCell13.Name = "tableCell13";
            this.tableCell13.Weight = 0.92130726402219132D;
            // 
            // tableCell27
            // 
            this.tableCell27.Dpi = 254F;
            this.tableCell27.Name = "tableCell27";
            this.tableCell27.StylePriority.UseTextAlignment = false;
            this.tableCell27.Text = "Korekta zaliczki:";
            this.tableCell27.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell27.Weight = 1.0812074503348639D;
            // 
            // DetailBand20
            // 
            this.DetailBand20.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table13});
            this.DetailBand20.Dpi = 254F;
            this.DetailBand20.HeightF = 38.1F;
            this.DetailBand20.Name = "DetailBand20";
            this.DetailBand20.StyleName = "ListaStylAutomatyczny";
            // 
            // GroupHeader20
            // 
            this.GroupHeader20.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table14,
                        this.label20});
            this.GroupHeader20.Dpi = 254F;
            this.GroupHeader20.HeightF = 103.1F;
            this.GroupHeader20.Name = "GroupHeader20";
            this.GroupHeader20.StyleName = "ListaStylAutomatyczny";
            // 
            // GroupFooter20
            // 
            this.GroupFooter20.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table15});
            this.GroupFooter20.Dpi = 254F;
            this.GroupFooter20.HeightF = 38.1F;
            this.GroupFooter20.Name = "GroupFooter20";
            this.GroupFooter20.StyleName = "ListaStylAutomatyczny";
            // 
            // table13
            // 
            this.table13.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table13.Dpi = 254F;
            this.table13.LocationFloat = new DevExpress.Utils.PointFloat(0.06007385F, 0F);
            this.table13.Name = "table13";
            this.table13.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow15});
            this.table13.SizeF = new System.Drawing.SizeF(1121.851F, 38.1F);
            this.table13.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow15
            // 
            this.tableRow15.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell76,
                        this.tableCell77,
                        this.tableCell78,
                        this.tableCell79,
                        this.colZaliczka});
            this.tableRow15.Dpi = 254F;
            this.tableRow15.Name = "tableRow15";
            this.tableRow15.Weight = 11.5D;
            // 
            // tableCell76
            // 
            this.tableCell76.Dpi = 254F;
            this.tableCell76.Name = "tableCell76";
            summary11.Func = DevExpress.XtraReports.UI.SummaryFunc.RecordNumber;
            summary11.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell76.Summary = summary11;
            this.tableCell76.Text = "Lp.";
            this.tableCell76.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell76.Weight = 0.023417930667325285D;
            // 
            // tableCell77
            // 
            this.tableCell77.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.DokumentyZaliczkowe.Numer")});
            this.tableCell77.Dpi = 254F;
            this.tableCell77.Name = "tableCell77";
            this.tableCell77.Text = "Numer";
            this.tableCell77.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell77.Weight = 0.13472160421639565D;
            // 
            // tableCell78
            // 
            this.tableCell78.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.DokumentyZaliczkowe.Data", "{0:d}")});
            this.tableCell78.Dpi = 254F;
            this.tableCell78.Name = "tableCell78";
            this.tableCell78.Text = "Data";
            this.tableCell78.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell78.Weight = 0.079069652123118436D;
            // 
            // tableCell79
            // 
            this.tableCell79.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.DokumentyZaliczkowe.BruttoCy")});
            this.tableCell79.Dpi = 254F;
            this.tableCell79.Name = "tableCell79";
            this.tableCell79.Text = "Wartość";
            this.tableCell79.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell79.Weight = 0.10086020439867781D;
            // 
            // colZaliczka
            // 
            this.colZaliczka.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.DokumentyZaliczkowe.fdZaliczka")});
            this.colZaliczka.Dpi = 254F;
            this.colZaliczka.Name = "colZaliczka";
            this.colZaliczka.Text = "Rozliczona zaliczka";
            this.colZaliczka.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.colZaliczka.Weight = 0.10189789821527616D;
            // 
            // table14
            // 
            this.table14.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table14.Dpi = 254F;
            this.table14.LocationFloat = new DevExpress.Utils.PointFloat(0.06011422F, 64.99999F);
            this.table14.Name = "table14";
            this.table14.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow16});
            this.table14.SizeF = new System.Drawing.SizeF(1121.852F, 38.1F);
            this.table14.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // label20
            // 
            this.label20.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.label20.Dpi = 254F;
            this.label20.LocationFloat = new DevExpress.Utils.PointFloat(0F, 25.00001F);
            this.label20.Multiline = true;
            this.label20.Name = "label20";
            this.label20.SizeF = new System.Drawing.SizeF(1701.74F, 40F);
            this.label20.StyleName = "TekstPomocniczyWyroznienieStyl";
            this.label20.StylePriority.UseBorders = false;
            this.label20.StylePriority.UseTextAlignment = false;
            this.label20.Text = "Faktury zaliczkowe";
            this.label20.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            // 
            // tableRow16
            // 
            this.tableRow16.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this._tableCell80,
                        this.tableCell81,
                        this.tableCell82,
                        this.tableCell83,
                        this.tableCell84});
            this.tableRow16.Dpi = 254F;
            this.tableRow16.Name = "tableRow16";
            this.tableRow16.Weight = 11.5D;
            // 
            // _tableCell80
            // 
            this._tableCell80.Dpi = 254F;
            this._tableCell80.Name = "_tableCell80";
            this._tableCell80.Text = "Lp.";
            this._tableCell80.Weight = 0.023417930667325285D;
            // 
            // tableCell81
            // 
            this.tableCell81.Dpi = 254F;
            this.tableCell81.Name = "tableCell81";
            this.tableCell81.Weight = 0.13472160421639565D;
            // 
            // tableCell82
            // 
            this.tableCell82.Dpi = 254F;
            this.tableCell82.Name = "tableCell82";
            this.tableCell82.Text = "Data";
            this.tableCell82.Weight = 0.079069652123118436D;
            // 
            // tableCell83
            // 
            this.tableCell83.Dpi = 254F;
            this.tableCell83.Name = "tableCell83";
            this.tableCell83.Text = "Wartość";
            this.tableCell83.Weight = 0.10086020439867781D;
            // 
            // tableCell84
            // 
            this.tableCell84.Dpi = 254F;
            this.tableCell84.Name = "tableCell84";
            this.tableCell84.Text = "Rozliczona zaliczka";
            this.tableCell84.Weight = 0.10189804183574834D;
            // 
            // table15
            // 
            this.table15.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table15.Dpi = 254F;
            this.table15.LocationFloat = new DevExpress.Utils.PointFloat(0.06007385F, 0F);
            this.table15.Name = "table15";
            this.table15.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow17});
            this.table15.SizeF = new System.Drawing.SizeF(1121.851F, 38.1F);
            this.table15.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow17
            // 
            this.tableRow17.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell85,
                        this.tableCell86,
                        this.tableCell87,
                        this.tableCell88,
                        this.tableCell89});
            this.tableRow17.Dpi = 254F;
            this.tableRow17.Name = "tableRow17";
            this.tableRow17.Weight = 11.5D;
            // 
            // tableCell85
            // 
            this.tableCell85.Dpi = 254F;
            this.tableCell85.Name = "tableCell85";
            this.tableCell85.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell85.Weight = 0.023417930667325285D;
            // 
            // tableCell86
            // 
            this.tableCell86.Dpi = 254F;
            this.tableCell86.Name = "tableCell86";
            this.tableCell86.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell86.Weight = 0.13472160421639565D;
            // 
            // tableCell87
            // 
            this.tableCell87.Dpi = 254F;
            this.tableCell87.Name = "tableCell87";
            this.tableCell87.Text = "Razem:";
            this.tableCell87.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell87.Weight = 0.079069652123118436D;
            // 
            // tableCell88
            // 
            this.tableCell88.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.DokumentyZaliczkowe.BruttoCy")});
            this.tableCell88.Dpi = 254F;
            this.tableCell88.Name = "tableCell88";
            summary12.IgnoreNullValues = true;
            summary12.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell88.Summary = summary12;
            this.tableCell88.Text = "Wartość";
            this.tableCell88.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell88.Weight = 0.10086020439868795D;
            // 
            // tableCell89
            // 
            this.tableCell89.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.DokumentyZaliczkowe.fdZaliczka")});
            this.tableCell89.Dpi = 254F;
            this.tableCell89.Name = "tableCell89";
            summary13.IgnoreNullValues = true;
            summary13.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell89.Summary = summary13;
            this.tableCell89.Text = "Rozliczona zaliczka";
            this.tableCell89.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell89.Weight = 0.10189785034177527D;
            // 
            // detailBand13
            // 
            this.detailBand13.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table29});
            this.detailBand13.Dpi = 254F;
            this.detailBand13.HeightF = 175F;
            this.detailBand13.Name = "detailBand13";
            // 
            // table29
            // 
            this.table29.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.table29.Dpi = 254F;
            this.table29.LocationFloat = new DevExpress.Utils.PointFloat(0F, 25.00001F);
            this.table29.Name = "table29";
            this.table29.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow35,
                        this.tableRow36,
                        this.tableRow31});
            this.table29.SizeF = new System.Drawing.SizeF(1319.226F, 150F);
            this.table29.StyleName = "TekstPomocniczyStyl";
            // 
            // tableRow35
            // 
            this.tableRow35.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell136,
                        this.tableCell137});
            this.tableRow35.Dpi = 254F;
            this.tableRow35.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableRow35.Name = "tableRow35";
            this.tableRow35.StylePriority.UseFont = false;
            this.tableRow35.Weight = 1D;
            // 
            // tableRow36
            // 
            this.tableRow36.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell139,
                        this.tableCell140});
            this.tableRow36.Dpi = 254F;
            this.tableRow36.Name = "tableRow36";
            this.tableRow36.Weight = 1D;
            // 
            // tableRow31
            // 
            this.tableRow31.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell4,
                        this.tableCell138});
            this.tableRow31.Dpi = 254F;
            this.tableRow31.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableRow31.Name = "tableRow31";
            this.tableRow31.StylePriority.UseFont = false;
            this.tableRow31.Weight = 1D;
            // 
            // tableCell136
            // 
            this.tableCell136.Borders = DevExpress.XtraPrinting.BorderSide.Bottom;
            this.tableCell136.Dpi = 254F;
            this.tableCell136.Name = "tableCell136";
            this.tableCell136.StylePriority.UseBorderDashStyle = false;
            this.tableCell136.StylePriority.UseBorders = false;
            this.tableCell136.StylePriority.UseTextAlignment = false;
            this.tableCell136.Text = "[Wydruk.KierunekZapłaty.Format]";
            this.tableCell136.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell136.Weight = 0.62309265261626323D;
            // 
            // tableCell137
            // 
            this.tableCell137.Borders = DevExpress.XtraPrinting.BorderSide.Bottom;
            this.tableCell137.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.BruttoCyPlus")});
            this.tableCell137.Dpi = 254F;
            this.tableCell137.Name = "tableCell137";
            this.tableCell137.StylePriority.UseBorders = false;
            this.tableCell137.StylePriority.UseTextAlignment = false;
            this.tableCell137.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell137.Weight = 1.3769073473837368D;
            // 
            // tableCell139
            // 
            this.tableCell139.Dpi = 254F;
            this.tableCell139.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell139.Name = "tableCell139";
            this.tableCell139.StylePriority.UseFont = false;
            this.tableCell139.StylePriority.UseTextAlignment = false;
            this.tableCell139.Text = "Słownie:";
            this.tableCell139.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell139.Weight = 0.62309269888214824D;
            // 
            // tableCell140
            // 
            this.tableCell140.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "BruttoCy", "{0:+t2}")});
            this.tableCell140.Dpi = 254F;
            this.tableCell140.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.tableCell140.Name = "tableCell140";
            this.tableCell140.StylePriority.UseFont = false;
            this.tableCell140.StylePriority.UseTextAlignment = false;
            this.tableCell140.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell140.Weight = 1.3769073011178519D;
            // 
            // tableCell4
            // 
            this.tableCell4.Borders = DevExpress.XtraPrinting.BorderSide.Top;
            this.tableCell4.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.Zapłacono", "{0} ")});
            this.tableCell4.Dpi = 254F;
            this.tableCell4.Name = "tableCell4";
            this.tableCell4.StylePriority.UseBorders = false;
            this.tableCell4.StylePriority.UseTextAlignment = false;
            this.tableCell4.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell4.Weight = 0.62309269888214824D;
            // 
            // tableCell138
            // 
            this.tableCell138.Borders = DevExpress.XtraPrinting.BorderSide.Top;
            this.tableCell138.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.ZaplaconoWszystkoRazem")});
            this.tableCell138.Dpi = 254F;
            this.tableCell138.Name = "tableCell138";
            this.tableCell138.StylePriority.UseBorders = false;
            this.tableCell138.StylePriority.UseFont = false;
            this.tableCell138.StylePriority.UseTextAlignment = false;
            this.tableCell138.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell138.Weight = 1.3769073011178519D;
            // 
            // detailBand14
            // 
            this.detailBand14.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.label21});
            this.detailBand14.Dpi = 254F;
            this.detailBand14.HeightF = 66.87495F;
            this.detailBand14.Name = "detailBand14";
            this.detailBand14.StyleName = "TekstPodstawowyStyl";
            // 
            // Grid2Lista
            // 
            this.Grid2Lista.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Grid2ListaWiersz,
                        this.Grid2ListaNagłówek});
            this.Grid2Lista.DataMember = "Zaliczki";
            this.Grid2Lista.DataSource = this.BusinessSource;
            this.Grid2Lista.Dpi = 254F;
            this.Grid2Lista.Level = 0;
            this.Grid2Lista.Name = "Grid2Lista";
            this.Grid2Lista.ReportPrintOptions.DetailCountOnEmptyDataSource = 0;
            // 
            // label21
            // 
            this.label21.Dpi = 254F;
            this.label21.LocationFloat = new DevExpress.Utils.PointFloat(0F, 25.00001F);
            this.label21.Multiline = true;
            this.label21.Name = "label21";
            this.label21.SizeF = new System.Drawing.SizeF(1701.8F, 40F);
            this.label21.StyleName = "TekstPomocniczyWyroznienieStyl";
            this.label21.Text = "Rozliczone wpłaty";
            this.label21.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            // 
            // Grid2ListaWiersz
            // 
            this.Grid2ListaWiersz.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table16});
            this.Grid2ListaWiersz.Dpi = 254F;
            this.Grid2ListaWiersz.HeightF = 38.1F;
            this.Grid2ListaWiersz.KeepTogether = true;
            this.Grid2ListaWiersz.Name = "Grid2ListaWiersz";
            this.Grid2ListaWiersz.SortFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending)});
            this.Grid2ListaWiersz.StyleName = "ListaStylAutomatyczny";
            // 
            // Grid2ListaNagłówek
            // 
            this.Grid2ListaNagłówek.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table17});
            this.Grid2ListaNagłówek.Dpi = 254F;
            this.Grid2ListaNagłówek.HeightF = 38.1F;
            this.Grid2ListaNagłówek.KeepTogether = true;
            this.Grid2ListaNagłówek.Name = "Grid2ListaNagłówek";
            this.Grid2ListaNagłówek.RepeatEveryPage = true;
            this.Grid2ListaNagłówek.StyleName = "ListaStylAutomatyczny";
            // 
            // table16
            // 
            this.table16.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table16.Dpi = 254F;
            this.table16.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table16.Name = "table16";
            this.table16.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow18});
            this.table16.SizeF = new System.Drawing.SizeF(1319.226F, 38.1F);
            this.table16.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow18
            // 
            this.tableRow18.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell90,
                        this.tableCell91,
                        this.tableCell92,
                        this.tableCell93,
                        this.tableCell94});
            this.tableRow18.Dpi = 254F;
            this.tableRow18.Name = "tableRow18";
            this.tableRow18.Weight = 11.5D;
            // 
            // tableCell90
            // 
            this.tableCell90.Dpi = 254F;
            this.tableCell90.Name = "tableCell90";
            summary14.Func = DevExpress.XtraReports.UI.SummaryFunc.RecordNumber;
            summary14.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell90.Summary = summary14;
            this.tableCell90.Text = "Lp.";
            this.tableCell90.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell90.Weight = 0.018518518518518517D;
            // 
            // tableCell91
            // 
            this.tableCell91.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Zaliczki.Zaplata.SposobZaplaty.Nazwa")});
            this.tableCell91.Dpi = 254F;
            this.tableCell91.Name = "tableCell91";
            this.tableCell91.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell91.Weight = 0.079743490334727954D;
            // 
            // tableCell92
            // 
            this.tableCell92.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Zaliczki.Zaplata.DataDokumentu", "{0:d}")});
            this.tableCell92.Dpi = 254F;
            this.tableCell92.Name = "tableCell92";
            this.tableCell92.Text = "Data";
            this.tableCell92.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell92.Weight = 0.036562583886868262D;
            // 
            // tableCell93
            // 
            this.tableCell93.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Zaliczki.KwotaRozliczonaDokumentu")});
            this.tableCell93.Dpi = 254F;
            this.tableCell93.Name = "tableCell93";
            this.tableCell93.Text = "Kwota";
            this.tableCell93.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell93.Weight = 0.06579022014104291D;
            // 
            // tableCell94
            // 
            this.tableCell94.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Zaliczki.Zaplata.NumerDokumentu")});
            this.tableCell94.Dpi = 254F;
            this.tableCell94.Name = "tableCell94";
            this.tableCell94.Text = "Numer";
            this.tableCell94.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell94.Weight = 0.10084976580266158D;
            // 
            // table17
            // 
            this.table17.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table17.Dpi = 254F;
            this.table17.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table17.Name = "table17";
            this.table17.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow19});
            this.table17.SizeF = new System.Drawing.SizeF(1319.226F, 38.1F);
            this.table17.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow19
            // 
            this.tableRow19.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell95,
                        this.tableCell96,
                        this.tableCell97,
                        this.tableCell98,
                        this.tableCell99});
            this.tableRow19.Dpi = 254F;
            this.tableRow19.Name = "tableRow19";
            this.tableRow19.Weight = 11.5D;
            // 
            // tableCell95
            // 
            this.tableCell95.Dpi = 254F;
            this.tableCell95.Name = "tableCell95";
            this.tableCell95.Text = "Lp.";
            this.tableCell95.Weight = 0.018518518518518517D;
            // 
            // tableCell96
            // 
            this.tableCell96.Dpi = 254F;
            this.tableCell96.Name = "tableCell96";
            this.tableCell96.Text = "Sposób zapłaty";
            this.tableCell96.Weight = 0.079743485018291954D;
            // 
            // tableCell97
            // 
            this.tableCell97.Dpi = 254F;
            this.tableCell97.Name = "tableCell97";
            this.tableCell97.Text = "Data";
            this.tableCell97.Weight = 0.036562603150840194D;
            // 
            // tableCell98
            // 
            this.tableCell98.Dpi = 254F;
            this.tableCell98.Name = "tableCell98";
            this.tableCell98.Text = "Kwota";
            this.tableCell98.Weight = 0.065790206193500164D;
            // 
            // tableCell99
            // 
            this.tableCell99.Dpi = 254F;
            this.tableCell99.Name = "tableCell99";
            this.tableCell99.Text = "Numer";
            this.tableCell99.Weight = 0.10084976580266843D;
            // 
            // detailBand16
            // 
            this.detailBand16.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.label1});
            this.detailBand16.Dpi = 254F;
            this.detailBand16.HeightF = 65.00009F;
            this.detailBand16.Name = "detailBand16";
            this.detailBand16.StyleName = "TekstPodstawowyStyl";
            // 
            // niezapłaconeLista
            // 
            this.niezapłaconeLista.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.niezapłaconeListaWiersz,
                        this.niezapłaconeListaNagłówek});
            this.niezapłaconeLista.DataMember = "Wydruk.Niezapłacone";
            this.niezapłaconeLista.DataSource = this.BusinessSource;
            this.niezapłaconeLista.Dpi = 254F;
            this.niezapłaconeLista.Level = 0;
            this.niezapłaconeLista.Name = "niezapłaconeLista";
            this.niezapłaconeLista.ReportPrintOptions.DetailCountOnEmptyDataSource = 0;
            // 
            // label1
            // 
            this.label1.Dpi = 254F;
            this.label1.LocationFloat = new DevExpress.Utils.PointFloat(0.06007385F, 25.00009F);
            this.label1.Name = "label1";
            this.label1.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.label1.SizeF = new System.Drawing.SizeF(1700F, 40F);
            this.label1.StyleName = "TekstPomocniczyWyroznienieStyl";
            this.label1.Text = "[Wydruk.KierunekZapłaty.Format]";
            this.label1.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            // 
            // niezapłaconeListaWiersz
            // 
            this.niezapłaconeListaWiersz.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table18});
            this.niezapłaconeListaWiersz.Dpi = 254F;
            this.niezapłaconeListaWiersz.HeightF = 38.1F;
            this.niezapłaconeListaWiersz.KeepTogether = true;
            this.niezapłaconeListaWiersz.Name = "niezapłaconeListaWiersz";
            this.niezapłaconeListaWiersz.SortFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending)});
            this.niezapłaconeListaWiersz.StyleName = "ListaStylAutomatyczny";
            // 
            // niezapłaconeListaNagłówek
            // 
            this.niezapłaconeListaNagłówek.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table19});
            this.niezapłaconeListaNagłówek.Dpi = 254F;
            this.niezapłaconeListaNagłówek.HeightF = 38.1F;
            this.niezapłaconeListaNagłówek.KeepTogether = true;
            this.niezapłaconeListaNagłówek.Name = "niezapłaconeListaNagłówek";
            this.niezapłaconeListaNagłówek.RepeatEveryPage = true;
            this.niezapłaconeListaNagłówek.StyleName = "ListaStylAutomatyczny";
            // 
            // table18
            // 
            this.table18.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table18.Dpi = 254F;
            this.table18.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table18.Name = "table18";
            this.table18.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow20});
            this.table18.SizeF = new System.Drawing.SizeF(1701.8F, 38.1F);
            this.table18.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow20
            // 
            this.tableRow20.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.SposobZaplaty,
                        this._tableCell101,
                        this.tableCell102,
                        this.platnik});
            this.tableRow20.Dpi = 254F;
            this.tableRow20.Name = "tableRow20";
            this.tableRow20.Weight = 11.5D;
            // 
            // SposobZaplaty
            // 
            this.SposobZaplaty.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.Niezapłacone.fdSposobZaplaty")});
            this.SposobZaplaty.Dpi = 254F;
            this.SposobZaplaty.Name = "SposobZaplaty";
            this.SposobZaplaty.Text = "Sposób zapłaty";
            this.SposobZaplaty.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.SposobZaplaty.Weight = 0.21279650440944531D;
            // 
            // _tableCell101
            // 
            this._tableCell101.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.Niezapłacone.Płatność.Termin", "{0:d}")});
            this._tableCell101.Dpi = 254F;
            this._tableCell101.Name = "_tableCell101";
            this._tableCell101.Text = "Termin";
            this._tableCell101.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this._tableCell101.Weight = 0.097278405285716185D;
            // 
            // tableCell102
            // 
            this.tableCell102.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.Niezapłacone.Kwota")});
            this.tableCell102.Dpi = 254F;
            this.tableCell102.Name = "tableCell102";
            this.tableCell102.Text = "Kwota";
            this.tableCell102.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell102.Weight = 0.14930303923904073D;
            // 
            // platnik
            // 
            this.platnik.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.Niezapłacone.fdPlatnik")});
            this.platnik.Dpi = 254F;
            this.platnik.Name = "platnik";
            this.platnik.Text = "Płatnik";
            this.platnik.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.platnik.Weight = 0.526660292332545D;
            // 
            // table19
            // 
            this.table19.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table19.Dpi = 254F;
            this.table19.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table19.Name = "table19";
            this.table19.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow21});
            this.table19.SizeF = new System.Drawing.SizeF(1701.8F, 38.1F);
            this.table19.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow21
            // 
            this.tableRow21.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this._tableCell104,
                        this._tableCell105,
                        this.tableCell106,
                        this._tableCell107});
            this.tableRow21.Dpi = 254F;
            this.tableRow21.Name = "tableRow21";
            this.tableRow21.Weight = 11.5D;
            // 
            // _tableCell104
            // 
            this._tableCell104.Dpi = 254F;
            this._tableCell104.Name = "_tableCell104";
            this._tableCell104.Text = "Sposób zapłaty";
            this._tableCell104.Weight = 0.064058692602559184D;
            // 
            // _tableCell105
            // 
            this._tableCell105.Dpi = 254F;
            this._tableCell105.Name = "_tableCell105";
            this._tableCell105.Text = "Termin";
            this._tableCell105.Weight = 0.029283975758761144D;
            // 
            // tableCell106
            // 
            this.tableCell106.Dpi = 254F;
            this.tableCell106.Name = "tableCell106";
            this.tableCell106.Text = "Kwota";
            this.tableCell106.Weight = 0.044945089020196352D;
            // 
            // _tableCell107
            // 
            this._tableCell107.Dpi = 254F;
            this._tableCell107.Name = "_tableCell107";
            this._tableCell107.Text = "Płatnik";
            this._tableCell107.Weight = 0.15854193787669948D;
            // 
            // detailBand18
            // 
            this.detailBand18.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.label2});
            this.detailBand18.Dpi = 254F;
            this.detailBand18.HeightF = 50.58333F;
            this.detailBand18.Name = "detailBand18";
            this.detailBand18.StyleName = "ListaNaglowekStyl";
            // 
            // label2
            // 
            this.label2.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.label2.Dpi = 254F;
            this.label2.LocationFloat = new DevExpress.Utils.PointFloat(0F, 10.58333F);
            this.label2.Name = "label2";
            this.label2.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.label2.SizeF = new System.Drawing.SizeF(1700F, 40F);
            this.label2.StyleName = "TekstPomocniczyWyroznienieStyl";
            this.label2.StylePriority.UseBorders = false;
            this.label2.Text = "[Wydruk.ZaplaconoInfo]";
            this.label2.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            // 
            // detailBand19
            // 
            this.detailBand19.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.label25});
            this.detailBand19.Dpi = 254F;
            this.detailBand19.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.detailBand19.HeightF = 72.1667F;
            this.detailBand19.Name = "detailBand19";
            this.detailBand19.StyleName = "TekstPomocniczyStyl";
            this.detailBand19.StylePriority.UseFont = false;
            // 
            // Grid_Magazynowe
            // 
            this.Grid_Magazynowe.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.Grid_MagazynoweListaWiersz,
                        this.Grid_MagazynoweListaNagłówek});
            this.Grid_Magazynowe.DataSource = this.BusinessSource;
            this.Grid_Magazynowe.Dpi = 254F;
            this.Grid_Magazynowe.Level = 0;
            this.Grid_Magazynowe.Name = "Grid_Magazynowe";
            this.Grid_Magazynowe.ReportPrintOptions.DetailCountOnEmptyDataSource = 0;
            // 
            // label25
            // 
            this.label25.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.label25.Dpi = 254F;
            this.label25.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.label25.LocationFloat = new DevExpress.Utils.PointFloat(0F, 25.00001F);
            this.label25.Name = "label25";
            this.label25.SizeF = new System.Drawing.SizeF(1691.3F, 40.64F);
            this.label25.StyleName = "TekstPomocniczyStyl";
            this.label25.StylePriority.UseFont = false;
            this.label25.Text = "Powiązane dokumenty magazynowe";
            // 
            // Grid_MagazynoweListaWiersz
            // 
            this.Grid_MagazynoweListaWiersz.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table20});
            this.Grid_MagazynoweListaWiersz.Dpi = 254F;
            this.Grid_MagazynoweListaWiersz.HeightF = 38.1F;
            this.Grid_MagazynoweListaWiersz.KeepTogether = true;
            this.Grid_MagazynoweListaWiersz.Name = "Grid_MagazynoweListaWiersz";
            this.Grid_MagazynoweListaWiersz.SortFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending)});
            this.Grid_MagazynoweListaWiersz.StyleName = "ListaStylAutomatyczny";
            // 
            // Grid_MagazynoweListaNagłówek
            // 
            this.Grid_MagazynoweListaNagłówek.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table21});
            this.Grid_MagazynoweListaNagłówek.Dpi = 254F;
            this.Grid_MagazynoweListaNagłówek.HeightF = 38.1F;
            this.Grid_MagazynoweListaNagłówek.KeepTogether = true;
            this.Grid_MagazynoweListaNagłówek.Name = "Grid_MagazynoweListaNagłówek";
            this.Grid_MagazynoweListaNagłówek.RepeatEveryPage = true;
            this.Grid_MagazynoweListaNagłówek.StyleName = "ListaStylAutomatyczny";
            // 
            // table20
            // 
            this.table20.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table20.Dpi = 254F;
            this.table20.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table20.Name = "table20";
            this.table20.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow22});
            this.table20.SizeF = new System.Drawing.SizeF(1701.8F, 38.1F);
            this.table20.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow22
            // 
            this.tableRow22.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.MagNumerCol,
                        this.MagDataCol,
                        this.MagDataDostawyCol,
                        this.MagWartCol});
            this.tableRow22.Dpi = 254F;
            this.tableRow22.Name = "tableRow22";
            this.tableRow22.Weight = 11.5D;
            // 
            // MagNumerCol
            // 
            this.MagNumerCol.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Numer.NumerPelny")});
            this.MagNumerCol.Dpi = 254F;
            this.MagNumerCol.Name = "MagNumerCol";
            this.MagNumerCol.Text = "Dokument";
            this.MagNumerCol.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.MagNumerCol.Weight = 0.090909090909090912D;
            // 
            // MagDataCol
            // 
            this.MagDataCol.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Data")});
            this.MagDataCol.Dpi = 254F;
            this.MagDataCol.Name = "MagDataCol";
            this.MagDataCol.Text = "Data wystawienia";
            this.MagDataCol.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.MagDataCol.Weight = 0.090909090909090912D;
            // 
            // MagDataDostawyCol
            // 
            this.MagDataDostawyCol.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Dostawa.Termin")});
            this.MagDataDostawyCol.Dpi = 254F;
            this.MagDataDostawyCol.Name = "MagDataDostawyCol";
            this.MagDataDostawyCol.Text = "Data dostawy";
            this.MagDataDostawyCol.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.MagDataDostawyCol.Weight = 0.090909090909090912D;
            // 
            // MagWartCol
            // 
            this.MagWartCol.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "")});
            this.MagWartCol.Dpi = 254F;
            this.MagWartCol.Name = "MagWartCol";
            this.MagWartCol.Text = "Wartość";
            this.MagWartCol.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.MagWartCol.Weight = 0.090909090909090912D;
            // 
            // table21
            // 
            this.table21.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table21.Dpi = 254F;
            this.table21.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table21.Name = "table21";
            this.table21.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow23});
            this.table21.SizeF = new System.Drawing.SizeF(1701.8F, 38.1F);
            this.table21.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow23
            // 
            this.tableRow23.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell108,
                        this.tableCell109,
                        this.tableCell110,
                        this.tableCell111});
            this.tableRow23.Dpi = 254F;
            this.tableRow23.Name = "tableRow23";
            this.tableRow23.Weight = 11.5D;
            // 
            // tableCell108
            // 
            this.tableCell108.Dpi = 254F;
            this.tableCell108.Name = "tableCell108";
            this.tableCell108.Text = "Dokument";
            this.tableCell108.Weight = 0.090909090909090912D;
            // 
            // tableCell109
            // 
            this.tableCell109.Dpi = 254F;
            this.tableCell109.Name = "tableCell109";
            this.tableCell109.Text = "Data wystawienia";
            this.tableCell109.Weight = 0.090909090909090912D;
            // 
            // tableCell110
            // 
            this.tableCell110.Dpi = 254F;
            this.tableCell110.Name = "tableCell110";
            this.tableCell110.Text = "Data dostawy";
            this.tableCell110.Weight = 0.090909090909090912D;
            // 
            // tableCell111
            // 
            this.tableCell111.Dpi = 254F;
            this.tableCell111.Name = "tableCell111";
            this.tableCell111.Text = "Wartość";
            this.tableCell111.Weight = 0.090909090909090912D;
            // 
            // Detail1
            // 
            this.Detail1.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table27,
                        this.table35});
            this.Detail1.Dpi = 254F;
            this.Detail1.HeightF = 76.19998F;
            this.Detail1.Name = "Detail1";
            this.Detail1.SortFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("Lp", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending)});
            this.Detail1.StyleName = "ListaStylAutomatyczny";
            // 
            // GroupHeader2
            // 
            this.GroupHeader2.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table34});
            this.GroupHeader2.Dpi = 254F;
            this.GroupHeader2.GroupFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("Workers.WydrukPozycji.SekcjaDokumentu", DevExpress.XtraReports.UI.XRColumnSortOrder.Descending)});
            this.GroupHeader2.HeightF = 63.50002F;
            this.GroupHeader2.Name = "GroupHeader2";
            this.GroupHeader2.StyleName = "TekstPomocniczyWyroznienieStyl";
            this.GroupHeader2.StylePriority.UseTextAlignment = false;
            // 
            // GroupHeader4
            // 
            this.GroupHeader4.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table33});
            this.GroupHeader4.Dpi = 254F;
            this.GroupHeader4.HeightF = 76.2F;
            this.GroupHeader4.KeepTogether = true;
            this.GroupHeader4.Level = 1;
            this.GroupHeader4.Name = "GroupHeader4";
            this.GroupHeader4.RepeatEveryPage = true;
            this.GroupHeader4.StyleName = "ListaStylAutomatyczny";
            // 
            // table27
            // 
            this.table27.Dpi = 254F;
            this.table27.LocationFloat = new DevExpress.Utils.PointFloat(0F, 38.09998F);
            this.table27.Name = "table27";
            this.table27.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow32});
            this.table27.SizeF = new System.Drawing.SizeF(1704F, 38.1F);
            // 
            // table35
            // 
            this.table35.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table35.Dpi = 254F;
            this.table35.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table35.Name = "table35";
            this.table35.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow44});
            this.table35.SizeF = new System.Drawing.SizeF(1704F, 38.1F);
            this.table35.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow32
            // 
            this.tableRow32.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell150});
            this.tableRow32.Dpi = 254F;
            this.tableRow32.Name = "tableRow32";
            this.tableRow32.Weight = 0.59999997597041088D;
            // 
            // tableCell150
            // 
            this.tableCell150.CanShrink = true;
            this.tableCell150.Dpi = 254F;
            this.tableCell150.Multiline = true;
            this.tableCell150.Name = "tableCell150";
            this.tableCell150.Text = "[NazwaResztaLinii]";
            this.tableCell150.Weight = 1D;
            // 
            // tableRow44
            // 
            this.tableRow44.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell171,
                        this.tableCell172,
                        this.tableCell173,
                        this.tableCell174,
                        this._tableCell176,
                        this._tableCell177,
                        this._tableCell178,
                        this.tableCell179,
                        this.tableCell180,
                        this._tableCell181,
                        this._tableCell182});
            this.tableRow44.Dpi = 254F;
            this.tableRow44.Name = "tableRow44";
            this.tableRow44.Weight = 0.92D;
            // 
            // tableCell171
            // 
            this.tableCell171.Dpi = 254F;
            this.tableCell171.Name = "tableCell171";
            this.tableCell171.StylePriority.UseTextAlignment = false;
            this.tableCell171.Text = "[Lp]";
            this.tableCell171.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell171.Weight = 0.031784913081932029D;
            // 
            // tableCell172
            // 
            this.tableCell172.Dpi = 254F;
            this.tableCell172.Name = "tableCell172";
            this.tableCell172.StylePriority.UseTextAlignment = false;
            this.tableCell172.Text = "[NazwaPierwszaLinia]";
            this.tableCell172.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell172.Weight = 0.060045323256338358D;
            // 
            // tableCell173
            // 
            this.tableCell173.Dpi = 254F;
            this.tableCell173.Name = "tableCell173";
            this.tableCell173.StylePriority.UseTextAlignment = false;
            this.tableCell173.Text = "[Ilosc.Value]";
            this.tableCell173.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell173.Weight = 0.060677396390074675D;
            // 
            // tableCell174
            // 
            this.tableCell174.Dpi = 254F;
            this.tableCell174.Name = "tableCell174";
            this.tableCell174.StylePriority.UseTextAlignment = false;
            this.tableCell174.Text = "[Symbol]";
            this.tableCell174.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell174.Weight = 0.038586323681116294D;
            // 
            // _tableCell176
            // 
            this._tableCell176.Dpi = 254F;
            this._tableCell176.Name = "_tableCell176";
            this._tableCell176.StylePriority.UseTextAlignment = false;
            this._tableCell176.Text = "[Rabat]";
            this._tableCell176.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this._tableCell176.Weight = 0.056957556340470089D;
            // 
            // _tableCell177
            // 
            this._tableCell177.Dpi = 254F;
            this._tableCell177.Name = "_tableCell177";
            this._tableCell177.StylePriority.UseTextAlignment = false;
            this._tableCell177.Text = "[CenaNettoPoRabacie]";
            this._tableCell177.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this._tableCell177.Weight = 0.077171558338635038D;
            // 
            // _tableCell178
            // 
            this._tableCell178.Dpi = 254F;
            this._tableCell178.Name = "_tableCell178";
            this._tableCell178.StylePriority.UseTextAlignment = false;
            this._tableCell178.Text = "[CenaBruttoPoRabacie]";
            this._tableCell178.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this._tableCell178.Weight = 0.078804284698314547D;
            // 
            // tableCell179
            // 
            this.tableCell179.Dpi = 254F;
            this.tableCell179.Name = "tableCell179";
            this.tableCell179.StylePriority.UseTextAlignment = false;
            this.tableCell179.Text = "[WartoscCy]";
            this.tableCell179.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell179.Weight = 0.0818972887511892D;
            // 
            // tableCell180
            // 
            this.tableCell180.Dpi = 254F;
            this.tableCell180.Multiline = true;
            this.tableCell180.Name = "tableCell180";
            this.tableCell180.StylePriority.UseTextAlignment = false;
            this.tableCell180.Text = "[DefinicjaStawki]";
            this.tableCell180.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell180.Weight = 0.0497822177673274D;
            // 
            // _tableCell181
            // 
            this._tableCell181.Dpi = 254F;
            this._tableCell181.Name = "_tableCell181";
            this._tableCell181.StylePriority.UseTextAlignment = false;
            this._tableCell181.Text = "[SWW]";
            this._tableCell181.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this._tableCell181.Weight = 0.059616835749382591D;
            // 
            // _tableCell182
            // 
            this._tableCell182.Dpi = 254F;
            this._tableCell182.Multiline = true;
            this._tableCell182.Name = "_tableCell182";
            this._tableCell182.StylePriority.UseTextAlignment = false;
            this._tableCell182.Text = "[RodzajKorektyOpis]";
            this._tableCell182.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this._tableCell182.Weight = 0.081694935485592438D;
            // 
            // table34
            // 
            this.table34.Dpi = 254F;
            this.table34.LocationFloat = new DevExpress.Utils.PointFloat(0F, 23.50002F);
            this.table34.Name = "table34";
            this.table34.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow43});
            this.table34.SizeF = new System.Drawing.SizeF(1704F, 40F);
            // 
            // tableRow43
            // 
            this.tableRow43.Borders = DevExpress.XtraPrinting.BorderSide.Bottom;
            this.tableRow43.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell170});
            this.tableRow43.Dpi = 254F;
            this.tableRow43.Name = "tableRow43";
            this.tableRow43.StylePriority.UseBorders = false;
            this.tableRow43.Weight = 1D;
            // 
            // tableCell170
            // 
            this.tableCell170.BorderColor = System.Drawing.Color.LightGray;
            this.tableCell170.Dpi = 254F;
            this.tableCell170.Name = "tableCell170";
            this.tableCell170.StylePriority.UseBorderColor = false;
            this.tableCell170.StylePriority.UseTextAlignment = false;
            this.tableCell170.Text = "[Workers.WydrukPozycji.SekcjaDokumentu.Format]";
            this.tableCell170.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell170.Weight = 3D;
            // 
            // table33
            // 
            this.table33.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table33.Dpi = 254F;
            this.table33.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table33.Name = "table33";
            this.table33.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow41,
                        this.tableRow42});
            this.table33.SizeF = new System.Drawing.SizeF(1704F, 76.2F);
            this.table33.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow41
            // 
            this.tableRow41.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell146,
                        this.tableCell147,
                        this.tableCell148,
                        this.tableCell149,
                        this._tableCell151,
                        this._tableCell152,
                        this._tableCell153,
                        this.tableCell154,
                        this._tableCell155,
                        this._tableCell156,
                        this._tableCell157});
            this.tableRow41.Dpi = 254F;
            this.tableRow41.Name = "tableRow41";
            this.tableRow41.Weight = 0.92D;
            // 
            // tableRow42
            // 
            this.tableRow42.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell158,
                        this.tableCell159,
                        this.tableCell160,
                        this.tableCell161,
                        this.tableCell163,
                        this.tableCell164,
                        this.tableCell165,
                        this.tableCell166,
                        this.tableCell167,
                        this.tableCell168,
                        this.tableCell169});
            this.tableRow42.Dpi = 254F;
            this.tableRow42.Name = "tableRow42";
            this.tableRow42.Weight = 0.92D;
            // 
            // tableCell146
            // 
            this.tableCell146.Dpi = 254F;
            this.tableCell146.Name = "tableCell146";
            this.tableCell146.RowSpan = 2;
            this.tableCell146.StylePriority.UseTextAlignment = false;
            this.tableCell146.Text = "Lp.";
            this.tableCell146.Weight = 0.031784913081932029D;
            // 
            // tableCell147
            // 
            this.tableCell147.Dpi = 254F;
            this.tableCell147.Name = "tableCell147";
            this.tableCell147.RowSpan = 2;
            this.tableCell147.Text = "Nazwa towaru/usługi";
            this.tableCell147.Weight = 0.060045301658714467D;
            // 
            // tableCell148
            // 
            this.tableCell148.Dpi = 254F;
            this.tableCell148.Name = "tableCell148";
            this.tableCell148.RowSpan = 2;
            this.tableCell148.Text = "Ilość";
            this.tableCell148.Weight = 0.06067739676898036D;
            // 
            // tableCell149
            // 
            this.tableCell149.Dpi = 254F;
            this.tableCell149.Name = "tableCell149";
            this.tableCell149.RowSpan = 2;
            this.tableCell149.Text = "jm.";
            this.tableCell149.Weight = 0.038586347931079956D;
            // 
            // _tableCell151
            // 
            this._tableCell151.Dpi = 254F;
            this._tableCell151.Name = "_tableCell151";
            this._tableCell151.RowSpan = 2;
            this._tableCell151.Text = "Rabat %";
            this._tableCell151.Weight = 0.05695755330922464D;
            // 
            // _tableCell152
            // 
            this._tableCell152.Dpi = 254F;
            this._tableCell152.Name = "_tableCell152";
            this._tableCell152.RowSpan = 2;
            this._tableCell152.Text = "Cena netto";
            this._tableCell152.Weight = 0.077171582588598686D;
            // 
            // _tableCell153
            // 
            this._tableCell153.Dpi = 254F;
            this._tableCell153.Name = "_tableCell153";
            this._tableCell153.RowSpan = 2;
            this._tableCell153.Text = "Cena brutto";
            this._tableCell153.Weight = 0.078804211948423575D;
            // 
            // tableCell154
            // 
            this.tableCell154.Dpi = 254F;
            this.tableCell154.Name = "tableCell154";
            this.tableCell154.RowSpan = 2;
            this.tableCell154.Text = "Wartość netto";
            this.tableCell154.Weight = 0.081897385751043855D;
            // 
            // _tableCell155
            // 
            this._tableCell155.Dpi = 254F;
            this._tableCell155.Multiline = true;
            this._tableCell155.Name = "_tableCell155";
            this._tableCell155.RowSpan = 2;
            this._tableCell155.Text = "Stawka VAT";
            this._tableCell155.Weight = 0.049782169267400075D;
            // 
            // _tableCell156
            // 
            this._tableCell156.Dpi = 254F;
            this._tableCell156.Name = "_tableCell156";
            this._tableCell156.RowSpan = 2;
            this._tableCell156.Text = "PKWiU";
            this._tableCell156.Weight = 0.059616835749382591D;
            // 
            // _tableCell157
            // 
            this._tableCell157.Dpi = 254F;
            this._tableCell157.Multiline = true;
            this._tableCell157.Name = "_tableCell157";
            this._tableCell157.RowSpan = 2;
            this._tableCell157.Text = "Zmiana\r\r\n(Przyczyna korekty)";
            this._tableCell157.Weight = 0.081694935485592438D;
            // 
            // tableCell158
            // 
            this.tableCell158.Dpi = 254F;
            this.tableCell158.Name = "tableCell158";
            this.tableCell158.StylePriority.UseTextAlignment = false;
            this.tableCell158.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell158.Weight = 0.031784913081932029D;
            // 
            // tableCell159
            // 
            this.tableCell159.Dpi = 254F;
            this.tableCell159.Name = "tableCell159";
            this.tableCell159.Text = " ";
            this.tableCell159.Weight = 0.060045298627469011D;
            // 
            // tableCell160
            // 
            this.tableCell160.Dpi = 254F;
            this.tableCell160.Name = "tableCell160";
            this.tableCell160.Weight = 0.060677399800225809D;
            // 
            // tableCell161
            // 
            this.tableCell161.Dpi = 254F;
            this.tableCell161.Name = "tableCell161";
            this.tableCell161.Weight = 0.038586347931079956D;
            // 
            // tableCell163
            // 
            this.tableCell163.Dpi = 254F;
            this.tableCell163.Name = "tableCell163";
            this.tableCell163.Weight = 0.05695755330922464D;
            // 
            // tableCell164
            // 
            this.tableCell164.Dpi = 254F;
            this.tableCell164.Name = "tableCell164";
            this.tableCell164.Weight = 0.077171582588598686D;
            // 
            // tableCell165
            // 
            this.tableCell165.Dpi = 254F;
            this.tableCell165.Name = "tableCell165";
            this.tableCell165.Weight = 0.078804211948423575D;
            // 
            // tableCell166
            // 
            this.tableCell166.Dpi = 254F;
            this.tableCell166.Name = "tableCell166";
            this.tableCell166.Weight = 0.081897385751043855D;
            // 
            // tableCell167
            // 
            this.tableCell167.Dpi = 254F;
            this.tableCell167.Name = "tableCell167";
            this.tableCell167.Weight = 0.049782169267400075D;
            // 
            // tableCell168
            // 
            this.tableCell168.Dpi = 254F;
            this.tableCell168.Name = "tableCell168";
            this.tableCell168.Weight = 0.059616835749382591D;
            // 
            // tableCell169
            // 
            this.tableCell169.Dpi = 254F;
            this.tableCell169.Name = "tableCell169";
            this.tableCell169.Weight = 0.081694935485592438D;
            // 
            // Detail4
            // 
            this.Detail4.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table37,
                        this.databaseSubReport2});
            this.Detail4.Dpi = 254F;
            this.Detail4.HeightF = 435.375F;
            this.Detail4.Name = "Detail4";
            // 
            // table37
            // 
            this.table37.BorderWidth = 0F;
            this.table37.Dpi = 254F;
            this.table37.LocationFloat = new DevExpress.Utils.PointFloat(0.06007385F, 25.00001F);
            this.table37.Name = "table37";
            this.table37.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tr_DokumentyPowiazane1,
                        this.tr_DokumentyPowiazane2,
                        this.tr_PoprzednieKorekty,
                        this.tr_OpisDok,
                        this.tr_OpisWydr});
            this.table37.SizeF = new System.Drawing.SizeF(1700F, 317.5F);
            this.table37.StylePriority.UseBorderWidth = false;
            // 
            // databaseSubReport2
            // 
            this.databaseSubReport2.Dpi = 254F;
            this.databaseSubReport2.LocationFloat = new DevExpress.Utils.PointFloat(0.06007385F, 376.955F);
            this.databaseSubReport2.Name = "databaseSubReport2";
            this.databaseSubReport2.ReportSourceName = "podpisy dokumentu handlowego";
            this.databaseSubReport2.SizeF = new System.Drawing.SizeF(1701.74F, 58.41998F);
            // 
            // tr_DokumentyPowiazane1
            // 
            this.tr_DokumentyPowiazane1.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell6,
                        this.tableCell7});
            this.tr_DokumentyPowiazane1.Dpi = 254F;
            this.tr_DokumentyPowiazane1.Name = "tr_DokumentyPowiazane1";
            this.tr_DokumentyPowiazane1.Weight = 1D;
            // 
            // tr_DokumentyPowiazane2
            // 
            this.tr_DokumentyPowiazane2.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell8,
                        this.tableCell9});
            this.tr_DokumentyPowiazane2.Dpi = 254F;
            this.tr_DokumentyPowiazane2.Name = "tr_DokumentyPowiazane2";
            this.tr_DokumentyPowiazane2.Weight = 1D;
            // 
            // tr_PoprzednieKorekty
            // 
            this.tr_PoprzednieKorekty.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell10,
                        this.tableCell11});
            this.tr_PoprzednieKorekty.Dpi = 254F;
            this.tr_PoprzednieKorekty.Name = "tr_PoprzednieKorekty";
            this.tr_PoprzednieKorekty.Weight = 1D;
            // 
            // tr_OpisDok
            // 
            this.tr_OpisDok.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell12});
            this.tr_OpisDok.Dpi = 254F;
            this.tr_OpisDok.Name = "tr_OpisDok";
            this.tr_OpisDok.Weight = 1D;
            // 
            // tr_OpisWydr
            // 
            this.tr_OpisWydr.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell14});
            this.tr_OpisWydr.Dpi = 254F;
            this.tr_OpisWydr.Name = "tr_OpisWydr";
            this.tr_OpisWydr.Weight = 1D;
            // 
            // tableCell6
            // 
            this.tableCell6.CanShrink = true;
            this.tableCell6.Dpi = 254F;
            this.tableCell6.Name = "tableCell6";
            this.tableCell6.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 0, 0, 0, 254F);
            this.tableCell6.RowSpan = 2;
            this.tableCell6.StyleName = "TekstPomocniczyWyroznienieStyl";
            this.tableCell6.StylePriority.UsePadding = false;
            this.tableCell6.StylePriority.UseTextAlignment = false;
            this.tableCell6.Text = "Dokumenty powiązane:";
            this.tableCell6.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell6.Weight = 0.63067914023250249D;
            // 
            // tableCell7
            // 
            this.tableCell7.CanShrink = true;
            this.tableCell7.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.NumeryNadrzędneZK")});
            this.tableCell7.Dpi = 254F;
            this.tableCell7.Name = "tableCell7";
            this.tableCell7.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 0, 0, 0, 254F);
            this.tableCell7.StylePriority.UsePadding = false;
            this.tableCell7.StylePriority.UseTextAlignment = false;
            this.tableCell7.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell7.Weight = 2.3693208597674973D;
            // 
            // tableCell8
            // 
            this.tableCell8.CanShrink = true;
            this.tableCell8.Dpi = 254F;
            this.tableCell8.Name = "tableCell8";
            this.tableCell8.Weight = 0.63067919396251515D;
            // 
            // tableCell9
            // 
            this.tableCell9.CanShrink = true;
            this.tableCell9.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.NumeryPodrzędneBK")});
            this.tableCell9.Dpi = 254F;
            this.tableCell9.Name = "tableCell9";
            this.tableCell9.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 0, 0, 0, 254F);
            this.tableCell9.StylePriority.UsePadding = false;
            this.tableCell9.StylePriority.UseTextAlignment = false;
            this.tableCell9.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell9.Weight = 2.3693208060374849D;
            // 
            // tableCell10
            // 
            this.tableCell10.CanShrink = true;
            this.tableCell10.Dpi = 254F;
            this.tableCell10.Name = "tableCell10";
            this.tableCell10.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 0, 0, 0, 254F);
            this.tableCell10.StyleName = "TekstPomocniczyWyroznienieStyl";
            this.tableCell10.StylePriority.UsePadding = false;
            this.tableCell10.StylePriority.UseTextAlignment = false;
            this.tableCell10.Text = "Poprzednie korekty:";
            this.tableCell10.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell10.Weight = 0.63149556777553861D;
            // 
            // tableCell11
            // 
            this.tableCell11.CanShrink = true;
            this.tableCell11.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.NumeryPoprzednichKorekt")});
            this.tableCell11.Dpi = 254F;
            this.tableCell11.Name = "tableCell11";
            this.tableCell11.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 0, 0, 0, 254F);
            this.tableCell11.StylePriority.UsePadding = false;
            this.tableCell11.StylePriority.UseTextAlignment = false;
            this.tableCell11.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell11.Weight = 2.3685044322244613D;
            // 
            // tableCell12
            // 
            this.tableCell12.CanShrink = true;
            this.tableCell12.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Opis")});
            this.tableCell12.Dpi = 254F;
            this.tableCell12.Multiline = true;
            this.tableCell12.Name = "tableCell12";
            this.tableCell12.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 0, 0, 0, 254F);
            this.tableCell12.StylePriority.UsePadding = false;
            this.tableCell12.StylePriority.UseTextAlignment = false;
            this.tableCell12.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell12.Weight = 3D;
            // 
            // tableCell14
            // 
            this.tableCell14.CanShrink = true;
            this.tableCell14.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.OpisWydruku")});
            this.tableCell14.Dpi = 254F;
            this.tableCell14.Multiline = true;
            this.tableCell14.Name = "tableCell14";
            this.tableCell14.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 0, 0, 0, 254F);
            this.tableCell14.StylePriority.UsePadding = false;
            this.tableCell14.StylePriority.UseTextAlignment = false;
            this.tableCell14.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
            this.tableCell14.Weight = 3D;
            // 
            // detailBand21
            // 
            this.detailBand21.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.pageBreak1,
                        this.label26});
            this.detailBand21.Dpi = 254F;
            this.detailBand21.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.detailBand21.HeightF = 61.00003F;
            this.detailBand21.Name = "detailBand21";
            this.detailBand21.StyleName = "TekstPomocniczyStyl";
            this.detailBand21.StylePriority.UseFont = false;
            // 
            // GridRozrachunkiLista
            // 
            this.GridRozrachunkiLista.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.GridRozrachunkiListaWiersz,
                        this.GridRozrachunkiListaNagłówek,
                        this.GridRozrachunkiListaStopka});
            this.GridRozrachunkiLista.DataMember = "Wydruk.RozrachunkiKontrahenta";
            this.GridRozrachunkiLista.DataSource = this.BusinessSource;
            this.GridRozrachunkiLista.Dpi = 254F;
            this.GridRozrachunkiLista.Level = 0;
            this.GridRozrachunkiLista.Name = "GridRozrachunkiLista";
            this.GridRozrachunkiLista.ReportPrintOptions.DetailCountOnEmptyDataSource = 0;
            // 
            // pageBreak1
            // 
            this.pageBreak1.Dpi = 254F;
            this.pageBreak1.LocationFloat = new DevExpress.Utils.PointFloat(0F, 5.08F);
            this.pageBreak1.Name = "pageBreak1";
            // 
            // label26
            // 
            this.label26.Borders = DevExpress.XtraPrinting.BorderSide.None;
            this.label26.Dpi = 254F;
            this.label26.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(238)));
            this.label26.LocationFloat = new DevExpress.Utils.PointFloat(0F, 20.35987F);
            this.label26.Name = "label26";
            this.label26.SizeF = new System.Drawing.SizeF(1704F, 40.64F);
            this.label26.StyleName = "TekstPomocniczyStyl";
            this.label26.StylePriority.UseFont = false;
            this.label26.Text = "Wykaz nierozliczonych należności";
            // 
            // GridRozrachunkiListaWiersz
            // 
            this.GridRozrachunkiListaWiersz.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table22});
            this.GridRozrachunkiListaWiersz.Dpi = 254F;
            this.GridRozrachunkiListaWiersz.HeightF = 38.1F;
            this.GridRozrachunkiListaWiersz.KeepTogether = true;
            this.GridRozrachunkiListaWiersz.Name = "GridRozrachunkiListaWiersz";
            this.GridRozrachunkiListaWiersz.SortFields.AddRange(new DevExpress.XtraReports.UI.GroupField[] {
                        new DevExpress.XtraReports.UI.GroupField("", DevExpress.XtraReports.UI.XRColumnSortOrder.Ascending)});
            this.GridRozrachunkiListaWiersz.StyleName = "ListaStylAutomatyczny";
            // 
            // GridRozrachunkiListaNagłówek
            // 
            this.GridRozrachunkiListaNagłówek.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table23});
            this.GridRozrachunkiListaNagłówek.Dpi = 254F;
            this.GridRozrachunkiListaNagłówek.HeightF = 38.1F;
            this.GridRozrachunkiListaNagłówek.KeepTogether = true;
            this.GridRozrachunkiListaNagłówek.Name = "GridRozrachunkiListaNagłówek";
            this.GridRozrachunkiListaNagłówek.StyleName = "ListaStylAutomatyczny";
            // 
            // GridRozrachunkiListaStopka
            // 
            this.GridRozrachunkiListaStopka.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.table24});
            this.GridRozrachunkiListaStopka.Dpi = 254F;
            this.GridRozrachunkiListaStopka.HeightF = 38.1F;
            this.GridRozrachunkiListaStopka.KeepTogether = true;
            this.GridRozrachunkiListaStopka.Name = "GridRozrachunkiListaStopka";
            this.GridRozrachunkiListaStopka.StyleName = "ListaStylAutomatyczny";
            // 
            // table22
            // 
            this.table22.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table22.Dpi = 254F;
            this.table22.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table22.Name = "table22";
            this.table22.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow24});
            this.table22.SizeF = new System.Drawing.SizeF(1701.8F, 38.1F);
            this.table22.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow24
            // 
            this.tableRow24.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell112,
                        this.tableCell113,
                        this.tableCell114,
                        this.tableCell115,
                        this.tableCell116});
            this.tableRow24.Dpi = 254F;
            this.tableRow24.Name = "tableRow24";
            this.tableRow24.Weight = 11.5D;
            // 
            // tableCell112
            // 
            this.tableCell112.Dpi = 254F;
            this.tableCell112.Name = "tableCell112";
            summary15.Func = DevExpress.XtraReports.UI.SummaryFunc.RecordNumber;
            summary15.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell112.Summary = summary15;
            this.tableCell112.Text = "Lp.";
            this.tableCell112.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell112.Weight = 0.017094017094017096D;
            // 
            // tableCell113
            // 
            this.tableCell113.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.RozrachunkiKontrahenta.NumerDokumentu")});
            this.tableCell113.Dpi = 254F;
            this.tableCell113.Name = "tableCell113";
            this.tableCell113.Text = "Numer";
            this.tableCell113.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell113.Weight = 0.085470085470085472D;
            // 
            // tableCell114
            // 
            this.tableCell114.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.RozrachunkiKontrahenta.SposobZaplaty.Nazwa")});
            this.tableCell114.Dpi = 254F;
            this.tableCell114.Name = "tableCell114";
            this.tableCell114.Text = "Forma płatności";
            this.tableCell114.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell114.Weight = 0.0641025641025641D;
            // 
            // tableCell115
            // 
            this.tableCell115.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.RozrachunkiKontrahenta.Termin")});
            this.tableCell115.Dpi = 254F;
            this.tableCell115.Name = "tableCell115";
            this.tableCell115.Text = "Termin";
            this.tableCell115.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell115.TextFormatString = "{0:dd.MM.yyyy}";
            this.tableCell115.Weight = 0.05128205128205128D;
            // 
            // tableCell116
            // 
            this.tableCell116.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.RozrachunkiKontrahenta.DoRozliczenia")});
            this.tableCell116.Dpi = 254F;
            this.tableCell116.Name = "tableCell116";
            this.tableCell116.Text = "Pozostaje";
            this.tableCell116.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell116.Weight = 0.0641025641025641D;
            // 
            // table23
            // 
            this.table23.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table23.Dpi = 254F;
            this.table23.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table23.Name = "table23";
            this.table23.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow25});
            this.table23.SizeF = new System.Drawing.SizeF(1701.8F, 38.1F);
            this.table23.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow25
            // 
            this.tableRow25.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell117,
                        this.tableCell118,
                        this.tableCell119,
                        this.tableCell120,
                        this.tableCell121});
            this.tableRow25.Dpi = 254F;
            this.tableRow25.Name = "tableRow25";
            this.tableRow25.Weight = 11.5D;
            // 
            // tableCell117
            // 
            this.tableCell117.Dpi = 254F;
            this.tableCell117.Name = "tableCell117";
            this.tableCell117.Text = "Lp.";
            this.tableCell117.Weight = 0.017094017094017096D;
            // 
            // tableCell118
            // 
            this.tableCell118.Dpi = 254F;
            this.tableCell118.Name = "tableCell118";
            this.tableCell118.Text = "Numer";
            this.tableCell118.Weight = 0.085470085470085472D;
            // 
            // tableCell119
            // 
            this.tableCell119.Dpi = 254F;
            this.tableCell119.Name = "tableCell119";
            this.tableCell119.Text = "Forma płatności";
            this.tableCell119.Weight = 0.0641025641025641D;
            // 
            // tableCell120
            // 
            this.tableCell120.Dpi = 254F;
            this.tableCell120.Name = "tableCell120";
            this.tableCell120.Text = "Termin";
            this.tableCell120.Weight = 0.05128205128205128D;
            // 
            // tableCell121
            // 
            this.tableCell121.Dpi = 254F;
            this.tableCell121.Name = "tableCell121";
            this.tableCell121.Text = "Pozostaje";
            this.tableCell121.Weight = 0.0641025641025641D;
            // 
            // table24
            // 
            this.table24.AnchorHorizontal = ((DevExpress.XtraReports.UI.HorizontalAnchorStyles)((DevExpress.XtraReports.UI.HorizontalAnchorStyles.Left | DevExpress.XtraReports.UI.HorizontalAnchorStyles.Right)));
            this.table24.Dpi = 254F;
            this.table24.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.table24.Name = "table24";
            this.table24.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
                        this.tableRow26});
            this.table24.SizeF = new System.Drawing.SizeF(1701.8F, 38.1F);
            this.table24.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // tableRow26
            // 
            this.tableRow26.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
                        this.tableCell122,
                        this.tableCell123,
                        this.tableCell124,
                        this.tableCell125,
                        this.tableCell126});
            this.tableRow26.Dpi = 254F;
            this.tableRow26.Name = "tableRow26";
            this.tableRow26.Weight = 11.5D;
            // 
            // tableCell122
            // 
            this.tableCell122.Dpi = 254F;
            this.tableCell122.Name = "tableCell122";
            this.tableCell122.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell122.Weight = 0.017094017094017096D;
            // 
            // tableCell123
            // 
            this.tableCell123.Dpi = 254F;
            this.tableCell123.Name = "tableCell123";
            this.tableCell123.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell123.Weight = 0.085470085470085472D;
            // 
            // tableCell124
            // 
            this.tableCell124.Dpi = 254F;
            this.tableCell124.Name = "tableCell124";
            this.tableCell124.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell124.Weight = 0.0641025641025641D;
            // 
            // tableCell125
            // 
            this.tableCell125.Dpi = 254F;
            this.tableCell125.Name = "tableCell125";
            this.tableCell125.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            this.tableCell125.Weight = 0.05128205128205128D;
            // 
            // tableCell126
            // 
            this.tableCell126.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
                        new DevExpress.XtraReports.UI.XRBinding("Text", null, "Wydruk.RozrachunkiKontrahenta.DoRozliczenia")});
            this.tableCell126.Dpi = 254F;
            this.tableCell126.Name = "tableCell126";
            summary16.IgnoreNullValues = true;
            summary16.Running = DevExpress.XtraReports.UI.SummaryRunning.Report;
            this.tableCell126.Summary = summary16;
            this.tableCell126.Text = "Pozostaje";
            this.tableCell126.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
            this.tableCell126.Weight = 0.0641025641025641D;
            // 
            // databaseSubReport1
            // 
            this.databaseSubReport1.Dpi = 254F;
            this.databaseSubReport1.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.databaseSubReport1.Name = "databaseSubReport1";
            this.databaseSubReport1.ReportSourceName = "nagłówek dokumentu handlowego";
            this.databaseSubReport1.SizeF = new System.Drawing.SizeF(1704F, 58.42F);
            // 
            // required_invisible_header
            // 
            this.required_invisible_header.DisplayFilters = Soneta.Business.UI.DxReports.Controls.FiltersVisibility.Never;
            this.required_invisible_header.Dpi = 254F;
            this.required_invisible_header.FiltersDescription = null;
            this.required_invisible_header.LocationFloat = new DevExpress.Utils.PointFloat(0.06007385F, 58.41996F);
            this.required_invisible_header.Name = "required_invisible_header";
            this.required_invisible_header.ParametersDescription = null;
            this.required_invisible_header.ReportSourceName = "nagłówek - dokument";
            this.required_invisible_header.SizeF = new System.Drawing.SizeF(1701.74F, 59.41998F);
            this.required_invisible_header.Title = null;
            this.required_invisible_header.Visible = false;
            // 
            // Detail2
            // 
            this.Detail2.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.label3});
            this.Detail2.Dpi = 254F;
            this.Detail2.HeightF = 129.6458F;
            this.Detail2.Name = "Detail2";
            // 
            // label3
            // 
            this.label3.Dpi = 254F;
            this.label3.Font = new System.Drawing.Font("Calibri", 12F, System.Drawing.FontStyle.Italic);
            this.label3.LocationFloat = new DevExpress.Utils.PointFloat(5.72914F, 29.10417F);
            this.label3.Multiline = true;
            this.label3.Name = "label3";
            this.label3.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.label3.SizeF = new System.Drawing.SizeF(505.3542F, 58.20834F);
            this.label3.StylePriority.UseFont = false;
            // 
            // Detail5
            // 
            this.Detail5.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
                        this.pageBreak2,
                        this.WykazNierozliczonychNależności});
            this.Detail5.Dpi = 254F;
            this.Detail5.HeightF = 60.85417F;
            this.Detail5.Name = "Detail5";
            // 
            // pageBreak2
            // 
            this.pageBreak2.Dpi = 254F;
            this.pageBreak2.LocationFloat = new DevExpress.Utils.PointFloat(0F, 5.08F);
            this.pageBreak2.Name = "pageBreak2";
            // 
            // WykazNierozliczonychNależności
            // 
            this.WykazNierozliczonychNależności.BorderColor = System.Drawing.Color.Transparent;
            this.WykazNierozliczonychNależności.Dpi = 254F;
            this.WykazNierozliczonychNależności.Font = new System.Drawing.Font("Calibri", 9F, System.Drawing.FontStyle.Bold);
            this.WykazNierozliczonychNależności.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
            this.WykazNierozliczonychNależności.Multiline = true;
            this.WykazNierozliczonychNależności.Name = "WykazNierozliczonychNależności";
            this.WykazNierozliczonychNależności.Padding = new DevExpress.XtraPrinting.PaddingInfo(5, 5, 0, 0, 254F);
            this.WykazNierozliczonychNależności.SizeF = new System.Drawing.SizeF(814.9167F, 52.91667F);
            this.WykazNierozliczonychNależności.StylePriority.UseBorderColor = false;
            this.WykazNierozliczonychNależności.StylePriority.UseFont = false;
            this.WykazNierozliczonychNależności.StylePriority.UseTextAlignment = false;
            this.WykazNierozliczonychNależności.Text = "Wykaz nierozliczonych należności: brak.";
            this.WykazNierozliczonychNależności.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleCenter;
            // 
            // fdSposobZaplaty
            // 
            this.fdSposobZaplaty.DataMember = "Wydruk.Niezapłacone";
            this.fdSposobZaplaty.Name = "fdSposobZaplaty";
            // 
            // fdPlatnik
            // 
            this.fdPlatnik.DataMember = "Wydruk.Niezapłacone";
            this.fdPlatnik.Name = "fdPlatnik";
            // 
            // fdZaliczka
            // 
            this.fdZaliczka.DataMember = "Wydruk.DokumentyZaliczkowe";
            this.fdZaliczka.Name = "fdZaliczka";
            // 
            // fdSekcjaDokumentu1
            // 
            this.fdSekcjaDokumentu1.DataMember = "ScriptingReport+MyParametryWydruku.PozycjeRazemWgTowaruICenyZKorektami";
            this.fdSekcjaDokumentu1.DataSource = this.BusinessSourceContext;
            this.fdSekcjaDokumentu1.Name = "fdSekcjaDokumentu1";
            // 
            // fdPrzyczynaZmiany1
            // 
            this.fdPrzyczynaZmiany1.DataMember = "ScriptingReport+MyParametryWydruku.PozycjeRazemWgTowaruICenyZKorektami";
            this.fdPrzyczynaZmiany1.DataSource = this.BusinessSourceContext;
            this.fdPrzyczynaZmiany1.Name = "fdPrzyczynaZmiany1";
            // 
            // pozBezOc
            // 
            this.pozBezOc.DataMember = "Wydruk.PozycjeRazem";
            this.pozBezOc.Name = "pozBezOc";
            // 
            // BusinessContext
            // 
            this.BusinessContext.Name = "BusinessContext";
            this.BusinessContext.StylesSource = "standardowy";
            // 
            // BusinessSource
            // 
            this.BusinessSource.DataKind = Soneta.Business.UI.DxReports.BusinessDataKind.CurrentList;
            this.BusinessSource.Name = "BusinessSource";
            this.BusinessSource.ShowValueProperties = true;
            // 
            // BusinessSourceContext
            // 
            this.BusinessSourceContext.DataKind = Soneta.Business.UI.DxReports.BusinessDataKind.Context;
            this.BusinessSourceContext.Name = "BusinessSourceContext";
            this.BusinessSourceContext.ShowValueProperties = true;
            // 
            // Sprzedaz
            // 
            this.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
                        this.topMarginBand1,
                        this.Raport,
                        this.bottomMarginBand1,
                        this.Dokument});
            this.CalculatedFields.AddRange(new DevExpress.XtraReports.UI.CalculatedField[] {
                        this.fdSposobZaplaty,
                        this.fdPlatnik,
                        this.fdZaliczka,
                        this.fdSekcjaDokumentu1,
                        this.fdPrzyczynaZmiany1,
                        this.pozBezOc});
            this.ComponentStorage.AddRange(new System.ComponentModel.IComponent[] {
                        this.BusinessContext,
                        this.BusinessSource,
                        this.BusinessSourceContext});
            this.DataSource = this.BusinessSource;
            this.DesignerOptions.ShowExportWarnings = false;
            this.Dpi = 254F;
            this.Font = new System.Drawing.Font("Calibri", 9F);
            this.Margins = new System.Drawing.Printing.Margins(198, 198, 200, 200);
            this.Name = "Sprzedaz";
            this.PageHeight = 2970;
            this.PageWidth = 2100;
            this.PaperKind = System.Drawing.Printing.PaperKind.A4;
            this.ReportUnit = DevExpress.XtraReports.UI.ReportUnit.TenthsOfAMillimeter;
            this.SnapGridSize = 25F;
            this.Version = "18.1";
            this.Watermark.ShowBehind = false;
            this.Watermark.TextTransparency = 90;
            ((System.ComponentModel.ISupportInitialize)(this.table36)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table3)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table32)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table4)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table6)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table25)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table5)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table7)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table8)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table9)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table26)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table10)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table11)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table12)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table2)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table13)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table14)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table15)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table29)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table16)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table17)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table18)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table19)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table20)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table21)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table27)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table35)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table34)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table33)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table37)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table22)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table23)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.table24)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this)).EndInit();
        }

        #endregion
    }
}
